@@ -1,10 +1,8 @@
 OC.L10N.register(
     "deck",
     {
-    "Hours" : "Uur",
-    "Minutes" : "Minute",
-    "File already exists" : "Lêer bestaan reeds",
     "Personal" : "Persoonlik",
+    "copy" : "kopie",
     "Done" : "Gereed",
     "The file was uploaded" : "Die lêer is opgelaai",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Die opgelaaide lêer oorskry die upload_max_filesize riglyn in php.ini",
@@ -13,21 +11,25 @@ OC.L10N.register(
     "No file was uploaded" : "Geen lêer is opgelaai",
     "Missing a temporary folder" : "Ontbrekende tydelike gids",
     "A PHP extension stopped the file upload" : "’n PHP-uitbreiding het die oplaai gestaak",
-    "Actions" : "Aksies",
-    "Close" : "Sluit",
+    "Cancel" : "Kanselleer",
+    "File already exists" : "Lêer bestaan reeds",
+    "Details" : "Besonderhede",
     "Tags" : "Etikette",
-    "Group" : "Groep",
-    "Loading" : "Laai tans..",
+    "Can edit" : "Kan redigeer",
+    "Can share" : "Kan deel",
+    "Delete" : "Skrap",
     "Edit" : "Wysig",
-    "Share" : "Deel",
-    "Create" : "Skep",
-    "Title" : "Titel",
-    "Cancel upload" : "Kanselleer oplaai",
-    "by" : "deur",
-    "Created:" : "Geskep:",
     "Due date" : "Sperdatum",
     "Description" : "Beskrywing",
-    "Saved" : "Bewaar",
-    "Settings" : "Instellings"
+    "Comments" : "Kommentare",
+    "Modified" : "Gewysig",
+    "Created" : "Geskep",
+    "Save" : "Stoor",
+    "Reply" : "Antwoord",
+    "Update" : "Werk by",
+    "seconds ago" : "sekondes gelede",
+    "Settings" : "Instellings",
+    "Share" : "Deel",
+    "An error occurred" : "'n Fout het voorgekom"
 },
 "nplurals=2; plural=(n != 1);");
