@@ -1,42 +1,37 @@
 OC.L10N.register(
     "deck",
     {
-    "Hours" : "ساعات",
-    "Minutes" : "دقائق",
-    "File already exists" : "الملف موجود مسبقاً",
     "Personal" : "شخصي",
     "Finished" : "مكتملة",
+    "copy" : "أنسخ",
     "Done" : "تم",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حجم الملف الذي تريد ترفيعه أعلى مما MAX_FILE_SIZE يسمح به في واجهة ال HTML.",
     "No file was uploaded" : "لم يتم رفع أي ملف",
     "Missing a temporary folder" : "المجلد المؤقت غير موجود",
-    "Actions" : "الإجراءات",
-    "Delete card" : "حذف البطاقة",
-    "Close" : "إغلاق",
+    "Cancel" : "إلغاء",
+    "File already exists" : "الملف موجود مسبقاً",
+    "Details" : "التفاصيل",
     "Sharing" : "المشاركة",
     "Tags" : "الوسوم",
     "Timeline" : "الخيط الزمني",
-    "Group" : "الفريق",
-    "Circle" : "حلقة",
-    "Loading" : "Loading",
+    "Undo" : "تراجع",
+    "Can edit" : "يمكنه التغيير",
+    "Can share" : "Can share",
+    "Delete" : "حذف ",
     "Edit" : "تعديل",
-    "Share" : "شارك",
-    "Update tag" : "تحديث الوسم",
-    "Edit tag" : "تعديل الوسم",
-    "Delete tag" : "حذف الوسم",
-    "Create" : "إنشاء",
-    "Status" : "الحالة",
-    "Title" : "العنوان",
-    "More actions" : "إجراءات أخرى",
-    "Cancel upload" : "إلغاء الرفع",
-    "by" : "من قبل",
-    "Delete attachment" : "حذف المرفق",
-    "Modified:" : "عُدل في :",
-    "Created:" : "تاريخ الإنشاء :",
     "Description" : "الوصف",
     "Attachments" : "المرفقات",
-    "Saved" : "تم الإحتفاظ به",
+    "Comments" : "تعليقات",
+    "Modified" : "آخر تعديل",
     "Upload attachment" : "رفع المرفقات",
-    "Settings" : "الإعدادات"
+    "Save" : "حفظ",
+    "Reply" : "رد",
+    "Update" : "تحديث",
+    "Delete card" : "حذف البطاقة",
+    "seconds ago" : "ثوان مضت",
+    "Settings" : "الإعدادات",
+    "Share" : "شارك",
+    "Options" : "الخيارات",
+    "An error occurred" : "طرأ هناك خطأ"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
