@@ -1,17 +1,6 @@
 OC.L10N.register(
     "deck",
     {
-    "Please provide a content for your comment." : "Zadejte obsah svého komentáře.",
-    "Posting the comment failed." : "Odeslání komentáře se nezdařilo.",
-    "The comment has been deleted" : "Komentář byl smazán",
-    "The associated stack is deleted as well, it will be restored as well." : "Související sloupec je také smazaný a bude také obnoven.",
-    "Restore associated stack" : "Obnovit související sloupec",
-    "Remove user from card" : "Odebrat uživatele z karty",
-    "Hours" : "Hodiny",
-    "Minutes" : "Minuty",
-    "Link to a board" : "Propojit s tabulí",
-    "Maximum file size of {size} exceeded" : "Překročena nejvyšší umožněná velikost souboru {size}",
-    "File already exists" : "Soubor už existuje",
     "You have created a new board {board}" : "Vytvořili jste tabuli {board}",
     "{user} has created a new board {board}" : "{user} vytvořil(a) novou tabuli {board}",
     "You have deleted the board {board}" : "Smazali jste tabuli {board}",
@@ -91,6 +80,7 @@ OC.L10N.register(
     "To review" : "K revizi",
     "Action needed" : "Nutná akce",
     "Later" : "Později",
+    "copy" : "kopie",
     "To do" : "Udělat",
     "Doing" : "Provádí se",
     "Done" : "Hotovo",
@@ -106,98 +96,122 @@ OC.L10N.register(
     "Could not write file to disk" : "Soubor se nedaří se zapsat na úložiště",
     "A PHP extension stopped the file upload" : "PHP rozšíření zastavilo nahrávání souboru.",
     "No file uploaded or file size exceeds maximum of %s" : "Nebyl nahrán žádný soubor nebo jeho velikost přesáhla %s",
-    "A kanban style project and personal management tool for Nextcloud" : "Nástroj pro projektový a osobní řízení ve stylu Kanban.",
+    "Personal planning and team project organization" : "Osobní plánování a organizování týmového projektu",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck je nástroj cílený na osobní nebo projektové plánování týmů v Kanban stylu, vestavěný v Nextcloud.\n\n\n- 📥 Zadávejte a uspořádávejte své úkoly do karet\n- 📄 Zapisujte si dodatečné poznámky \n- 🔖 Přiřazujte štítky pro ještě lepší organizaci\n- 👥 Sdílejte se svým týmem, přáteli nebo rodinou\n- 🚀 Dostaňte svůj projekt pod kontrolu",
+    "Create new board" : "Vytvořit novou tabuli",
+    "new board" : "nová tabule",
     "Select the board to link to a project" : "Vyberte tabuli kterou propojit s projektem",
     "Select board" : "Vybrat tabuli",
-    "Add a new stack" : "Přidat nový sloupec",
-    "Submit" : "Odeslat",
-    "Show archived cards" : "Zobrazit archivované karty",
-    "Hide archived cards" : "Skrýt archivované karty",
-    "Toggle compact mode" : "Vyp/zap. kompaktní režim",
-    "Show board details" : "Zobrazit podrobnosti o tabuli",
-    "All Boards" : "Všechny tabule",
-    "Archived boards" : "Archivované tabule",
-    "Share board" : "Sdílet tabuli",
+    "Select the card to link to a project" : "Vyberte kartu kterou propojit s projektem",
+    "Select a board" : "Vybrat tabuli",
+    "Select a card" : "Vybrat tabuli",
+    "Link to card" : "Propojit s kartou",
+    "Cancel" : "Storno",
+    "File already exists" : "Soubor už existuje",
+    "A file with the name {filename} already exists." : "Soubor nazvaný {filename} už existuje.",
+    "Do you want to overwrite it?" : "Chcete položku přepsat?",
+    "Overwrite file" : "Přepsat soubor",
+    "Keep existing file" : "Ponechat existující soubor",
+    "This board is read only" : "Tato tabule je pouze pro čtení",
+    "Drop your files to upload" : "Přetáhněte sem soubory, které chcete nahrát",
     "Archived cards" : "Archivované karty",
-    "Actions" : "Akce",
-    "Drop your files here to upload it to the card" : "Soubory ke kartě připojíte přetažením sem",
-    "Assign card to me" : "Přiřadit kartu mě",
-    "Unassign card from me" : "Zrušit přiřazení karty mě",
-    "Archive card" : "Archivovat kartu",
-    "Unarchive card" : "Zrušit archivaci karty",
-    "Delete card" : "Smazat kartu",
-    "Enter a card title" : "Zadejte nadpis karty",
-    "Add card" : "Přidat kartu",
-    "Close" : "Zavřít",
+    "Add new list" : "Přidat nový seznam",
+    "List name" : "Název seznamu",
+    "Apply filter" : "Uplatnit filtr",
+    "Filter by tag" : "Filtrovat podle příznaků",
+    "Filter by assigned user" : "Filtrovat podle uživatele, který je úkolem pověřen",
+    "Filter by due date" : "Filtrovat podle termínu",
+    "Overdue" : "Po termínu",
+    "Next 24 hours" : "Následujících 24 hodin",
+    "Next 7 days" : "Příštích 7 dnů",
+    "Next 30 days" : "Příštích 30 dnů",
+    "No due date" : "Žádný termín",
+    "Show archived cards" : "Zobrazit archivované karty",
+    "Toggle compact mode" : "Vyp/zap. kompaktní režim",
+    "Details" : "Podrobnosti",
+    "Loading board" : "Načítání tabule",
+    "Board not found" : "Tabule nenalezena",
     "Sharing" : "Sdílení",
     "Tags" : "Štítky",
     "Deleted items" : "Smazané položky",
     "Timeline" : "Časová osa",
-    "Select users or groups to share with" : "Vyberte uživatele nebo skupiny pro sdílení",
-    "Group" : "Skupina",
-    "Circle" : "Okruh",
-    "No matching user or group found." : "Nevyhovuje žádný uživatel ani skupina",
-    "Loading" : "Načítání",
-    "Edit" : "Upravit",
-    "Share" : "Sdílet",
-    "Manage" : "Spravovat",
-    "Discard share" : "Zahodit sdílení",
-    "Sharing has been disabled for your account." : "Sdílení bylo pro váš účet zakázáno.",
-    "Update tag" : "Aktualizovat štítek",
-    "Edit tag" : "Upravit štítek",
-    "Delete tag" : "Smazat štítek",
-    "Create" : "Vytvořit",
-    "Create a new tag" : "Vytvořit nový štítek",
-    "Deleted stacks" : "Smazané sloupce",
+    "Deleted lists" : "Smazané seznamy",
+    "Undo" : "Vrátit zpět",
     "Deleted cards" : "Smazané karty",
-    "Status" : "Stav",
-    "No archived boards to display" : "Žádné archivované tabule k zobrazení",
-    "No shared boards to display" : "Žádné sdílené tabule k zobrazení",
-    "Title" : "Název",
-    "Members" : "Členové",
-    "More actions" : "Více akcí",
-    "Edit board" : "Upravit tabuli",
-    "Archive board" : "Archivovat tabuli",
-    "Unarchive board" : "Vrátit tabuli zpět z archivu",
-    "Delete board" : "Smazat tabuli",
-    "Update board" : "Aktualizovat tabuli",
-    "Reset board" : "Vrátit tabuli do předchozího stavu",
-    "Undo board deletion - Otherwise the board will be deleted during the next cronjob run." : "Vrátit smazání tabule – jinak bude nadobro odstraněna během příštího spuštění naplánovaných úloh.",
-    "Create new board" : "Vytvořit novou tabuli",
-    "New board title" : "Název nové tabule",
-    "Create board" : "Vytvořit tabuli",
-    "Select an attachment" : "Vybrat přílohu",
-    "Cancel upload" : "Zrušit nahrávání",
-    "by" : "od",
-    "Undo file deletion - Otherwise the file will be deleted during the next cronjob run." : "Vrátit smazání souboru – jinak bude trvale smazán při dalším běhu naplánované úlohy.",
-    "Undo file deletion" : "Vzít zpět smazání souboru",
-    "Insert the file into the description" : "Vložte soubor do popisu",
-    "Delete attachment" : "Smazat přílohu",
-    "Modified:" : "Změněno:",
-    "Created:" : "Vytvořeno:",
-    "Choose a tag" : "Zvolte štítek",
-    "Add a tag" : "Přidat štítek",
-    "Select tags" : "Výběr štítků",
-    "Assign users" : "Přiřadit uživatele",
-    "Choose a user to assign" : "Zvolte uživatele kterého přiřadit",
-    "Assign this card to a user" : "Přiřadit tuto kartu uživateli",
+    "Share board with a user, group or circle …" : "Sdílet tabuli s uživatelem, skupinou nebo okruhem…",
+    "Board owner" : "Vlastník tabule",
+    "(Group)" : "(Skupina)",
+    "(Circle)" : "(Okruh)",
+    "Can edit" : "Může upravovat",
+    "Can share" : "Může sdílet",
+    "Can manage" : "Může spravovat",
+    "Delete" : "Smazat",
+    "Add a new stack" : "Přidat nový sloupec",
+    "Delete list" : "Smazat seznam",
+    "Add card" : "Přidat kartu",
+    "Add a new card" : "Přidat novou kartu",
+    "Edit" : "Upravit",
+    "Add a new tag" : "Přidat nový štítek",
+    "title and color value must be provided" : "je třeba zadat nadpis a zvolit barvu",
+    "Add this attachment" : "Přidat tuto přílohu",
+    "Delete Attachment" : "Smazat přílohu",
+    "Restore Attachment" : "Obnovit přílohu",
+    "Assign a tag to this card…" : "Přiřadit této kartě štítek…",
+    "Assign to users" : "Přiřadit k uživatelům",
+    "Assign to users/groups/circles" : "Přiřadit uživatelům/skupinám/okruhům",
+    "Assign a user to this card…" : "Přiřadit uživatele k této kartě…",
     "Due date" : "Termín",
-    "Click to set" : "Klikn. vyberte",
+    "Set a due date" : "Vybrat termín",
     "Remove due date" : "Odstranit termín",
     "Description" : "Popis",
-    "Attachments" : "Přílohy",
-    "Saved" : "Uloženo",
-    "Unsaved changes" : "Neuložené změny",
-    "Insert attachment" : "Vložit přílohu",
+    "(Unsaved)" : "(Neuloženo)",
+    "(Saving…)" : "(Ukládání…)",
     "Formatting help" : "Nápověda k formátování",
+    "Add Attachment" : "Přidat přílohu",
+    "Edit description" : "Upravit popis",
+    "View description" : "Zobrazit popis",
+    "Attachments" : "Přílohy",
+    "Comments" : "Komentáře",
+    "Choose attachment" : "Zvolte přílohu",
+    "Modified" : "Změněno",
+    "Created" : "Vytvořeno",
     "Upload attachment" : "Nahrát přílohu",
-    "Add a card description…" : "Přidejte popis karty…",
+    "No comments yet. Begin the discussion!" : "Zatím bez komentářů. Zahajte diskuzi!",
+    "Save" : "Uložit",
+    "The comment cannot be empty." : "Komentář je třeba vyplnit",
+    "The comment cannot be longer than 1000 characters." : "Délka komentáře může být nejvýše 1 000 znaků.",
+    "In reply to" : "V odpověď na",
+    "Reply" : "Odpovědět",
+    "Update" : "Aktualizovat",
+    "(group)" : "(skupina)",
+    "(circle)" : "(okruh)",
+    "Assign to me" : "Přiřadit mě",
+    "Delete card" : "Smazat kartu",
+    "Move card" : "Přesunout kartu",
+    "Card details" : "Podrobnosti o kartě",
+    "Select a stack" : "Vybrat sloupec",
+    "seconds ago" : "před několika sekundami",
+    "All boards" : "Všechny tabule",
+    "Archived boards" : "Archivované tabule",
     "Shared boards" : "Sdílené tabule",
-    "Move board to archive" : "Přesunout tabuli do archivu",
-    "Create a new board" : "Vytvořit novou tabuli",
     "Settings" : "Nastavení",
-    "Limit deck to groups" : "Omezit Deck na skupiny",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Omezení nastavené pro Deck brání uživatelům, kteří nejsou součástí těchto skupin, ve vytváření vlastních tabulí. Nicméně i tak ale pořád budou moci pracovat na tabulích, které jsou jim nasdíleny."
+    "Limit deck usage of groups" : "Omezit využití deck na skupiny",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Omezení nastavené pro Deck brání uživatelům, kteří nejsou součástí těchto skupin, ve vytváření vlastních tabulí. Nicméně i tak ale pořád budou moci pracovat na tabulích, které jsou jim nasdíleny.",
+    "New board title" : "Název nové tabule",
+    "Share" : "Sdílet",
+    "Options" : "Volby",
+    "Edit board" : "Upravit tabuli",
+    "An error occurred" : "Došlo k chybě",
+    "Clone board" : "Klonovat tabuli",
+    "Archive board" : "Archivovat tabuli",
+    "Unarchive board" : "Vrátit tabuli zpět z archivu",
+    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Opravdu chcete tabuly {title} smazat? Toto smaže veškerá data této tabule.",
+    "Delete the board?" : "Smazat tabuli?",
+    "Delete board" : "Smazat tabuli",
+    "Board details" : "Podrobnosti o desce",
+    "Link to a board" : "Propojit s tabulí",
+    "Link to a card" : "Propojit s kartou",
+    "Something went wrong" : "Něco se pokazilo",
+    "Maximum file size of {size} exceeded" : "Překročena nejvyšší umožněná velikost souboru {size}"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
