@@ -1,10 +1,6 @@
 OC.L10N.register(
     "deck",
     {
-    "Remove user from card" : "Fjern bruger fra kort",
-    "Hours" : "Timer",
-    "Minutes" : "Minutter",
-    "File already exists" : "Fil findes allerede",
     "Deck" : "Deck",
     "Personal" : "Personlig",
     "The card \"%s\" on \"%s\" has reached its due date." : "Kortet \"%s\" på \"%s\" har nået sin udløbsdato.",
@@ -14,72 +10,55 @@ OC.L10N.register(
     "To review" : "Gennemse",
     "Action needed" : "Handling påkrævet",
     "Later" : "Senere",
+    "copy" : "kopiér",
     "Done" : "Færdig",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Den uploadede fil overstiger upload_max_filesize direktivet i php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uploadede fil overstiger MAX_FILE_SIZE indstilingen, som specificeret i HTML formularen",
     "No file was uploaded" : "Ingen fil uploadet",
     "Missing a temporary folder" : "Manglende midlertidig mappe.",
-    "A kanban style project and personal management tool for Nextcloud" : "Et Kanban-inspireret projekt- og styringsværktøj til Nextcloud",
-    "Add a new stack" : "Tilføj en ny stak",
-    "Submit" : "Tilføj",
+    "Create new board" : "Opret ny liste",
+    "Cancel" : "Annullér",
+    "File already exists" : "Fil findes allerede",
+    "Do you want to overwrite it?" : "Vil du overskrive den?",
+    "Drop your files to upload" : "Drop dine filer for at uploade",
     "Show archived cards" : "Vis arkiverede kort",
-    "Hide archived cards" : "Skjul arkiverede kort",
-    "All Boards" : "Alle lister",
-    "Archived boards" : "Arkiverede lister",
-    "Actions" : "Handlinger",
-    "Archive card" : "Arkivér kort",
-    "Delete card" : "Slet kort",
-    "Enter a card title" : "Angiv titel på kort",
-    "Add card" : "Tilføj kort",
-    "Close" : "Luk",
+    "Details" : "Detaljer",
     "Sharing" : "Deling",
     "Tags" : "Mærkat",
-    "Select users or groups to share with" : "Vælg brugere eller grupper og dele med",
-    "Group" : "Gruppe",
-    "Circle" : "Cirkel",
-    "No matching user or group found." : "Ingen bruger eller gruppe fundet",
-    "Loading" : "Loader",
+    "Undo" : "Fortryd",
+    "Can edit" : "Can edit",
+    "Can share" : "Kan dele",
+    "Delete" : "Slet",
+    "Add a new stack" : "Tilføj en ny stak",
+    "Delete list" : "Slet liste",
+    "Add card" : "Tilføj kort",
     "Edit" : "Redigér",
+    "Due date" : "Forfaldsdato",
+    "Remove due date" : "Fjern forfaldsdato",
+    "Description" : "Beskrivelse",
+    "Formatting help" : "Hjælp til formatering",
+    "Attachments" : "Vedhæftede filer",
+    "Comments" : "Kommentarer",
+    "Modified" : "Ændret",
+    "Created" : "Oprettet",
+    "Upload attachment" : "Upload vedhæftning",
+    "Save" : "Gem",
+    "Reply" : "Besvar",
+    "Update" : "Opdatér",
+    "(group)" : "(gruppe)",
+    "Delete card" : "Slet kort",
+    "Move card" : "Flyt kort",
+    "seconds ago" : "sekunder siden",
+    "Archived boards" : "Arkiverede lister",
+    "Shared boards" : "Delte lister",
+    "Settings" : "Indstillinger",
+    "New board title" : "Ny titel på liste",
     "Share" : "Del",
-    "Manage" : "Administrer ",
-    "Discard share" : "Kasser deling",
-    "Create" : "Opret",
-    "Create a new tag" : "Opret et nyt mærkat",
-    "Status" : "Status",
-    "Title" : "Titel",
-    "Members" : "Medlemmer",
-    "More actions" : "Flere handlinger",
     "Edit board" : "Rediger liste",
+    "An error occurred" : "Der var en fejl",
     "Archive board" : "Arkivér liste",
     "Unarchive board" : "Annuller arkivering af liste",
     "Delete board" : "Slet liste",
-    "Undo board deletion - Otherwise the board will be deleted during the next cronjob run." : "Fortryd sletning af board - Ellers vil boardet blive slettet ved næste cronjob kørsel.",
-    "Create new board" : "Opret ny liste",
-    "New board title" : "Ny titel på liste",
-    "Create board" : "Opret liste",
-    "Cancel upload" : "Annuller upload ",
-    "by" : "af",
-    "Modified:" : "Ændret:",
-    "Created:" : "Oprettet:",
-    "Choose a tag" : "Vælg et tag",
-    "Add a tag" : "Tilføj et tag",
-    "Select tags" : "Vælg tags",
-    "Assign users" : "Tildel brugere",
-    "Choose a user to assign" : "Vælg en bruger at tildele til",
-    "Assign this card to a user" : "Tildel dette kort til en bruger",
-    "Due date" : "Forfaldsdato",
-    "Click to set" : "Klik for at sætte",
-    "Remove due date" : "Fjern forfaldsdato",
-    "Description" : "Beskrivelse",
-    "Attachments" : "Vedhæftede filer",
-    "Saved" : "Gemt",
-    "Unsaved changes" : "Ikke gemte ændringer",
-    "Formatting help" : "Hjælp til formatering",
-    "Upload attachment" : "Upload vedhæftning",
-    "Add a card description…" : "Tilføj en beskrivelse...",
-    "Shared boards" : "Delte lister",
-    "Move board to archive" : "Flyt liste til arkiv",
-    "Create a new board" : "Opret ny liste",
-    "Settings" : "Indstillinger"
+    "Board details" : "Liste detaljer"
 },
 "nplurals=2; plural=(n != 1);");
