@@ -1,12 +1,6 @@
 OC.L10N.register(
     "deck",
     {
-    "Please provide a content for your comment." : "Please provide a content for your comment.",
-    "Posting the comment failed." : "Posting the comment failed.",
-    "Remove user from card" : "Remove user from card",
-    "Hours" : "Hours",
-    "Minutes" : "Minutes",
-    "File already exists" : "File already exists",
     "Deck" : "Deck",
     "Personal" : "Personal",
     "The card \"%s\" on \"%s\" has reached its due date." : "The card \"%s\" on \"%s\" has reached its due date.",
@@ -25,67 +19,46 @@ OC.L10N.register(
     "Missing a temporary folder" : "Missing a temporary folder",
     "Could not write file to disk" : "Could not write file to disk",
     "A PHP extension stopped the file upload" : "A PHP extension stopped the file upload",
-    "A kanban style project and personal management tool for Nextcloud" : "A kanban style project and personal management tool for Nextcloud",
-    "Add a new stack" : "Add a new stack",
-    "Submit" : "Submit",
+    "Create new board" : "Create new board",
+    "Cancel" : "Cancel",
+    "File already exists" : "File already exists",
+    "Do you want to overwrite it?" : "Do you want to overwrite it?",
+    "Filter by tag" : "Filter by tag",
     "Show archived cards" : "Show archived cards",
-    "Hide archived cards" : "Hide archived cards",
-    "All Boards" : "All Boards",
-    "Archived boards" : "Archived boards",
-    "Actions" : "Actions",
-    "Archive card" : "Archive card",
-    "Delete card" : "Delete card",
-    "Enter a card title" : "Enter a card title",
-    "Add card" : "Add card",
-    "Close" : "Close",
+    "Details" : "Details",
     "Sharing" : "Sharing",
     "Tags" : "Tags",
-    "Select users or groups to share with" : "Select users or groups to share with",
-    "Group" : "Group",
-    "Circle" : "Circle",
-    "No matching user or group found." : "No matching user or group found.",
-    "Loading" : "Loading",
+    "Undo" : "Undo",
+    "Can edit" : "Can edit",
+    "Can share" : "Can share",
+    "Delete" : "Delete",
+    "Add a new stack" : "Add a new stack",
+    "Add card" : "Add card",
     "Edit" : "Edit",
+    "Due date" : "Due date",
+    "Remove due date" : "Remove due date",
+    "Description" : "Description",
+    "Formatting help" : "Formatting help",
+    "Attachments" : "Attachments",
+    "Comments" : "Comments",
+    "Modified" : "Modified",
+    "Created" : "Created",
+    "Upload attachment" : "Upload attachment",
+    "Save" : "Save",
+    "Reply" : "Reply",
+    "Update" : "Update",
+    "(group)" : "(group)",
+    "Delete card" : "Delete card",
+    "seconds ago" : "seconds ago",
+    "Archived boards" : "Archived boards",
+    "Shared boards" : "Shared boards",
+    "Settings" : "Settings",
+    "New board title" : "New board title",
     "Share" : "Share",
-    "Manage" : "Manage",
-    "Discard share" : "Discard share",
-    "Create" : "Create",
-    "Create a new tag" : "Create a new tag",
-    "Status" : "Status",
-    "Title" : "Title",
-    "Members" : "Members",
-    "More actions" : "More actions",
     "Edit board" : "Edit board",
     "Archive board" : "Archive board",
     "Unarchive board" : "Unarchive board",
     "Delete board" : "Delete board",
-    "Undo board deletion - Otherwise the board will be deleted during the next cronjob run." : "Undo board deletion - Otherwise the board will be deleted during the next cronjob run.",
-    "Create new board" : "Create new board",
-    "New board title" : "New board title",
-    "Create board" : "Create board",
-    "Cancel upload" : "Cancel upload",
-    "by" : "by",
-    "Modified:" : "Modified:",
-    "Created:" : "Created:",
-    "Choose a tag" : "Choose a tag",
-    "Add a tag" : "Add a tag",
-    "Select tags" : "Select tags",
-    "Assign users" : "Assign users",
-    "Choose a user to assign" : "Choose a user to assign",
-    "Assign this card to a user" : "Assign this card to a user",
-    "Due date" : "Due date",
-    "Click to set" : "Click to set",
-    "Remove due date" : "Remove due date",
-    "Description" : "Description",
-    "Attachments" : "Attachments",
-    "Saved" : "Saved",
-    "Unsaved changes" : "Unsaved changes",
-    "Formatting help" : "Formatting help",
-    "Upload attachment" : "Upload attachment",
-    "Add a card description…" : "Add a card description…",
-    "Shared boards" : "Shared boards",
-    "Move board to archive" : "Move board to archive",
-    "Create a new board" : "Create a new board",
-    "Settings" : "Settings"
+    "Board details" : "Board details"
 },
 "nplurals=2; plural=(n != 1);");
