@@ -1,8 +1,6 @@
 OC.L10N.register(
     "deck",
     {
-    "Hours" : "Tunnid",
-    "Minutes" : "Minutid",
     "Personal" : "Isiklik",
     "Finished" : "Lõpetatud",
     "Later" : "Hiljem",
@@ -11,25 +9,26 @@ OC.L10N.register(
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Üleslaetud fail on suurem, kui MAX_FILE_SIZE atribuut, mis seadistati HTML vormis",
     "No file was uploaded" : "Ühtegi faili ei latud üles",
     "Missing a temporary folder" : "Ajutine kausta on puudu",
-    "Actions" : "Tegevused",
-    "Close" : "Sulge",
+    "Cancel" : "Loobu",
+    "Details" : "Üksikasjad",
     "Sharing" : "Jagamine",
     "Tags" : "Sildid",
-    "Group" : "Grupp",
-    "Circle" : "Ring",
-    "Loading" : "Laadimine",
+    "Can edit" : "Võib redigeerida",
+    "Can share" : "Can share",
+    "Delete" : "Kustuta",
     "Edit" : "Redigeeri",
-    "Share" : "Jaga",
-    "Create" : "Loo",
-    "Status" : "Staatus",
-    "Title" : "Pealkiri",
-    "Cancel upload" : "Tühista üleslaadimine",
-    "by" : "lisas",
-    "Modified:" : "Muudetud:",
-    "Created:" : "Loodud:",
     "Due date" : "Tähtaeg",
     "Description" : "Kirjeldus",
-    "Saved" : "Salvestatud",
-    "Settings" : "Seaded"
+    "Comments" : "Kommentaarid",
+    "Modified" : "Muudetud",
+    "Created" : "Loodud",
+    "Save" : "Salvesta",
+    "Reply" : "Vasta",
+    "Update" : "Uuenda",
+    "(group)" : "(grupp)",
+    "seconds ago" : "sekundit tagasi",
+    "Settings" : "Seaded",
+    "Share" : "Jaga",
+    "An error occurred" : "Tekkis tõrge"
 },
 "nplurals=2; plural=(n != 1);");
