@@ -1,30 +1,31 @@
 OC.L10N.register(
     "deck",
     {
-    "Hours" : "Jam",
-    "Minutes" : "Menit",
     "Personal" : "Personal",
     "Finished" : "Selesai",
     "Done" : "Selesai",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Berkas yang diunggah melampaui direktif MAX_FILE_SIZE yang ditentukan dalam formulir HTML.",
     "No file was uploaded" : "Tidak ada berkas yang diunggah",
     "Missing a temporary folder" : "Folder sementara tidak ada",
-    "Actions" : "Tindakan",
-    "Close" : "Tutup",
+    "Cancel" : "Membatalkan",
+    "Details" : "Detil",
     "Sharing" : "Berbagi",
     "Tags" : "Tag",
-    "Group" : "Grup",
-    "Loading" : "Memuat",
+    "Undo" : "Undo",
+    "Can edit" : "Can edit",
+    "Can share" : "Can share",
+    "Delete" : "Hapus",
     "Edit" : "Sunting",
-    "Share" : "Bagikan",
-    "Create" : "Buat",
-    "Title" : "Judul",
-    "Cancel upload" : "Batal unggah",
-    "by" : "oleh",
-    "Modified:" : "Diubah:",
-    "Created:" : "Dibuat:",
     "Description" : "Deskrisi",
-    "Saved" : "Disimpan",
-    "Settings" : "Setelan"
+    "Comments" : "Komentar",
+    "Modified" : "Dimodifikasi",
+    "Created" : "Dibuat",
+    "Save" : "Simpan",
+    "Reply" : "Balas",
+    "Update" : "Perbarui",
+    "(group)" : "(grup)",
+    "seconds ago" : "beberapa detik yang lalu",
+    "Settings" : "Setelan",
+    "Share" : "Bagikan"
 },
 "nplurals=1; plural=0;");
