@@ -1,17 +1,6 @@
 OC.L10N.register(
     "deck",
     {
-    "Please provide a content for your comment." : "コメントの内容を入力してください。",
-    "Posting the comment failed." : "コメントを投稿できませんでした。",
-    "The comment has been deleted" : "コメントが削除されました",
-    "The associated stack is deleted as well, it will be restored as well." : "関連するスタックも削除され、復元されます。",
-    "Restore associated stack" : "関連するスタックを復元する",
-    "Remove user from card" : "カードからユーザーを削除",
-    "Hours" : "時間",
-    "Minutes" : "分",
-    "Link to a board" : "ボードへのリンク",
-    "Maximum file size of {size} exceeded" : "最大ファイルサイズ（{size}）を超えています",
-    "File already exists" : "ファイルはすでに存在します",
     "You have created a new board {board}" : "あなたは新しいボード {board} を作成しました。",
     "{user} has created a new board {board}" : "{user} が新しいボード {board} を作成しました",
     "You have deleted the board {board}" : "あなたはボード {board} を削除しました。",
@@ -91,6 +80,7 @@ OC.L10N.register(
     "To review" : "レビューする",
     "Action needed" : "必要なアクション",
     "Later" : "後",
+    "copy" : "コピー",
     "To do" : "To do",
     "Doing" : "行うこと",
     "Done" : "完了",
@@ -106,98 +96,61 @@ OC.L10N.register(
     "Could not write file to disk" : "ディスクにファイルを書き込めませんでした",
     "A PHP extension stopped the file upload" : "PHP拡張でファイルのアップロードが停止されています",
     "No file uploaded or file size exceeds maximum of %s" : "ファイルがアップロードされていないか、ファイルサイズが最大 %s を超えています",
-    "A kanban style project and personal management tool for Nextcloud" : "Nextcloud用のカンバンスタイルプロジェクトと個人管理ツール",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "DeckはNextcloudと統合した、チームの個人計画とプロジェクトの組織化を目的としたカンバンスタイルの組織ツールです。\n\n\n- 📥 タスクをカードに追加して整理する\n- 📄 マークダウンで追加のメモを書き留めます\n- 🔖 より良い組織のためにラベルを割り当てる\n- 👥 あなたのチーム、友人、家族と共有する\n- 📎 ファイルを添付してマークダウンの説明に埋め込む\n- 💬 コメントを使ってあなたのチームと話し合う\n- ⚡ アクティビティの流れの変化を追跡する\n- 🚀 プロジェクトを整理する",
+    "Create new board" : "新しいボードを作成",
     "Select the board to link to a project" : "プロジェクトにリンクするボードを選択",
     "Select board" : "ボードを選択",
-    "Add a new stack" : "新しいスタックを追加する",
-    "Submit" : "了解",
-    "Show archived cards" : "アーカイブされたカードを表示する",
-    "Hide archived cards" : "アーカイブされたカードを非表示にする",
-    "Toggle compact mode" : "コンパクトモードの切り替え",
-    "Show board details" : "ボードの詳細を表示",
-    "All Boards" : "すべてのボード",
-    "Archived boards" : "アーカイブ済みのボード",
-    "Share board" : "ボードを共有",
+    "Cancel" : "キャンセル",
+    "File already exists" : "ファイルはすでに存在します",
+    "Do you want to overwrite it?" : "上書きしますか？",
     "Archived cards" : "カードをアーカイブ",
-    "Actions" : "アクション",
-    "Drop your files here to upload it to the card" : "ファイルをここにドロップしてカードをアップロードします",
-    "Assign card to me" : "カードを自分に割り当てる",
-    "Unassign card from me" : "カードの割り当てを解除する",
-    "Archive card" : "カードをアーカイブ",
-    "Unarchive card" : "カードのアーカイブを解除する",
-    "Delete card" : "カードを削除する",
-    "Enter a card title" : "カードのタイトルを入力してください",
-    "Add card" : "カードを追加",
-    "Close" : "閉じる",
-    "Sharing" : "共有",
+    "Filter by tag" : "タグによるフィルター",
+    "Show archived cards" : "アーカイブされたカードを表示する",
+    "Toggle compact mode" : "コンパクトモードの切り替え",
+    "Details" : "詳細",
+    "Sharing" : "共有中",
     "Tags" : "タグ",
     "Deleted items" : "削除されたアイテム",
     "Timeline" : "タイムライン",
-    "Select users or groups to share with" : "共有するユーザーまたはグループを選択する",
-    "Group" : "グループ",
-    "Circle" : "サークル",
-    "No matching user or group found." : "一致するユーザーまたはグループが見つかりません。",
-    "Loading" : "読み込み中",
-    "Edit" : "編集",
-    "Share" : "共有",
-    "Manage" : "管理",
-    "Discard share" : "共有をやめる",
-    "Sharing has been disabled for your account." : "あなたのアカウントでは共有が無効になっています",
-    "Update tag" : "タグを更新する",
-    "Edit tag" : "タグを編集",
-    "Delete tag" : "タグを削除",
-    "Create" : "作成",
-    "Create a new tag" : "新しいタグを作成",
-    "Deleted stacks" : "削除済みのスタック",
+    "Undo" : "元に戻す",
     "Deleted cards" : "削除済みのカード",
-    "Status" : "ステータス",
-    "No archived boards to display" : "表示するアーカイブボードはありません",
-    "No shared boards to display" : "表示する共有ボードがありません",
-    "Title" : "タイトル",
-    "Members" : "メンバー",
-    "More actions" : "その他のアクション",
+    "(Group)" : "(グループ)",
+    "Can edit" : "編集可能",
+    "Can share" : "共有可能",
+    "Delete" : "削除",
+    "Add a new stack" : "新しいスタックを追加する",
+    "Add card" : "カードを追加",
+    "Edit" : "編集",
+    "Due date" : "期限",
+    "Remove due date" : "期限を削除",
+    "Description" : "説明",
+    "Formatting help" : "ヘルプの書式設定",
+    "Attachments" : "添付ファイル",
+    "Comments" : "コメント",
+    "Modified" : "更新日時",
+    "Created" : "作成時刻",
+    "Upload attachment" : "添付ファイルをアップロードする",
+    "Save" : "保存",
+    "Reply" : "返信",
+    "Update" : "更新",
+    "(group)" : "(グループ)",
+    "Delete card" : "カードを削除する",
+    "Move card" : "カードの移動",
+    "seconds ago" : "数秒前",
+    "Archived boards" : "アーカイブ済みのボード",
+    "Shared boards" : "共有ボード",
+    "Settings" : "設定",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "デッキ作成制限は、設定したグループに非所属のユーザーがボードを作成できないようにします。非所属ユーザーは共有されているボードでのみ作業できます。",
+    "New board title" : "新しいボードのタイトル",
+    "Share" : "共有",
+    "Options" : "オプション",
     "Edit board" : "ボードを編集",
+    "An error occurred" : "エラーが発生しました",
     "Archive board" : "ボードをアーカイブ",
     "Unarchive board" : "ボードのアーカイブを解除",
     "Delete board" : "ボードを削除",
-    "Update board" : "ボードを更新する",
-    "Reset board" : "リセットボード",
-    "Undo board deletion - Otherwise the board will be deleted during the next cronjob run." : "ボードの削除を取り消す - それ以外の場合は、次のcronジョブの実行中にボードが削除されます。",
-    "Create new board" : "新しいボードを作成",
-    "New board title" : "新しいボードのタイトル",
-    "Create board" : "ボードを作成",
-    "Select an attachment" : "添付ファイルを選択",
-    "Cancel upload" : "アップロードをキャンセル",
-    "by" : "by",
-    "Undo file deletion - Otherwise the file will be deleted during the next cronjob run." : "ファイルの削除を元に戻す - それ以外の場合は、次のcronジョブの実行中にファイルが削除されます。",
-    "Undo file deletion" : "削除したファイルを元に戻す",
-    "Insert the file into the description" : "説明にファイルを挿入する",
-    "Delete attachment" : "添付ファイルを削除する",
-    "Modified:" : "更新:",
-    "Created:" : "作成:",
-    "Choose a tag" : "タグを選択",
-    "Add a tag" : "タグを追加",
-    "Select tags" : "タグを選択..",
-    "Assign users" : "ユーザーを割り当てる",
-    "Choose a user to assign" : "割り当てるユーザーを選択する",
-    "Assign this card to a user" : "このカードをユーザーに割り当てる",
-    "Due date" : "期限",
-    "Click to set" : "時刻設定",
-    "Remove due date" : "期限を削除",
-    "Description" : "説明",
-    "Attachments" : "添付ファイル",
-    "Saved" : "保存しました",
-    "Unsaved changes" : "保存していない変更点",
-    "Insert attachment" : "添付ファイルを挿入する",
-    "Formatting help" : "ヘルプの書式設定",
-    "Upload attachment" : "添付ファイルをアップロードする",
-    "Add a card description…" : "カードの説明を追加...",
-    "Shared boards" : "共有ボード",
-    "Move board to archive" : "ボードをアーカイブに移動する",
-    "Create a new board" : "新しいボードを作成",
-    "Settings" : "設定",
-    "Limit deck to groups" : "デッキ作成制限",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "デッキ作成制限は、設定したグループに非所属のユーザーがボードを作成できないようにします。非所属ユーザーは共有されているボードでのみ作業できます。"
+    "Board details" : "ボードの詳細",
+    "Link to a board" : "ボードへのリンク",
+    "Maximum file size of {size} exceeded" : "最大ファイルサイズ（{size}）を超えています"
 },
 "nplurals=1; plural=0;");
