@@ -5,16 +5,15 @@ OC.L10N.register(
     "Done" : "Done",
     "No file was uploaded" : "ವರ್ಗಾವಣೆಗೆ ﻿ಯಾವುದೇ ಕಡತಗಳು ಕಂಡುಬಂದಿಲ್ಲ",
     "Missing a temporary folder" : "ತಾತ್ಕಾಲಿಕ ಕಡತಕೋಶ ದೊರೆಕುತ್ತಿಲ್ಲ",
-    "Close" : "ಮುಚ್ಚು",
+    "Cancel" : "﻿ರದ್ದು",
     "Sharing" : "﻿ಹಂಚಿಕೆ",
-    "Group" : "﻿ಗುಂಪು",
-    "Loading" : "Loading",
+    "Can edit" : "Can edit",
+    "Can share" : "Can share",
+    "Delete" : "﻿ಅಳಿಸಿ",
     "Edit" : "ಸಂಪಾದಿಸು",
-    "Share" : "﻿ಹಂಚಿಕೊಳ್ಳಿ",
-    "Create" : "ಸೃಷ್ಟಿಸಿ",
-    "Title" : "ಶೀರ್ಷಿಕೆ",
-    "Cancel upload" : "﻿ವರ್ಗಾವಣೆ ರದ್ದು ಮಾಡಿ",
-    "Saved" : "﻿ಉಳಿಸಿದ",
-    "Settings" : "ಆಯ್ಕೆ"
+    "Modified" : "﻿ಬದಲಾಯಿಸಿದ",
+    "Save" : "﻿ಉಳಿಸಿ",
+    "Settings" : "ಆಯ್ಕೆ",
+    "Share" : "﻿ಹಂಚಿಕೊಳ್ಳಿ"
 },
 "nplurals=2; plural=(n > 1);");
