@@ -1,24 +1,14 @@
 OC.L10N.register(
     "deck",
     {
-    "Please provide a content for your comment." : "Pateikite savo komentaro turinį.",
-    "Posting the comment failed." : "Komentaro paskelbimas patyrė nesėkmę.",
-    "The comment has been deleted" : "Komentaras ištrintas",
-    "Restore associated stack" : "Atkurti susietą dėklą",
-    "Remove user from card" : "Šalinti naudotoją iš kortelės",
-    "Hours" : "Valandos",
-    "Minutes" : "Minutės",
-    "Link to a board" : "Susieti su plokšte",
-    "Maximum file size of {size} exceeded" : "Viršytas maksimalus {size} failo dydis",
-    "File already exists" : "Failas jau yra",
-    "You have created a new board {board}" : "Jūs sukūrėte naują plokštę {board}",
-    "{user} has created a new board {board}" : "{user} sukūrė naują plokštę {board}",
-    "You have deleted the board {board}" : "Jūs ištrynėte plokštę {board}",
-    "{user} has deleted the board {board}" : "{user} ištrynė plokštę {board}",
-    "You have restored the board {board}" : "Jūs atkūrėte plokštę {board}",
-    "{user} has restored the board {board}" : "{user} atkūrė plokštę {board}",
-    "You have shared the board {board} with {acl}" : "Jūs pradėjote bendrinti plokštę {board} su {acl}",
-    "{user} has shared the board {board} with {acl}" : "{user} pradėjo bendrinti plokštę {board} su {acl}",
+    "You have created a new board {board}" : "Jūs sukūrėte naują lentą {board}",
+    "{user} has created a new board {board}" : "{user} sukūrė naują lentą {board}",
+    "You have deleted the board {board}" : "Jūs ištrynėte lentą {board}",
+    "{user} has deleted the board {board}" : "{user} ištrynė lentą {board}",
+    "You have restored the board {board}" : "Jūs atkūrėte lentą {board}",
+    "{user} has restored the board {board}" : "{user} atkūrė lentą {board}",
+    "You have shared the board {board} with {acl}" : "Jūs pradėjote bendrinti lentą {board} su {acl}",
+    "{user} has shared the board {board} with {acl}" : "{user} pradėjo bendrinti lentą {board} su {acl}",
     "You have removed {acl} from the board {board}" : "Jūs pašalinote {acl} iš plokštės {board}",
     "{user} has removed {acl} from the board {board}" : "{user} pašalino {acl} iš plokštės {board}",
     "You have renamed the board {before} to {board}" : "Jūs pervadinote plokštę {before} į {board}",
@@ -76,13 +66,19 @@ OC.L10N.register(
     "Changes in the <strong>Deck app</strong>" : "Pakeitimai <strong>Darbų programėlėje</strong>",
     "A <strong>comment</strong> was created on a card" : "Kortelėje buvo sukurtas <strong>komentaras</strong>",
     "Personal" : "Asmeniniai",
+    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kortelę \"%s\" ties \"%s\" priskyrė jums %s.",
+    "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user} priskyrė jums kortelę \"%s\" ties \"%s\".",
+    "The card \"%s\" on \"%s\" has reached its due date." : "Kortelė \"%s\" ties \"%s\" pasiekė savo galutinį terminą.",
+    "%s has mentioned you in a comment on \"%s\"." : "%s paminėjo jus komentare ties \"%s\".",
     "{user} has mentioned you in a comment on \"%s\"." : "{user} paminėjo jus komentare ties \"%s\".",
+    "The board \"%s\" has been shared with you by %s." : "Plokštę \"%s\" su jumis bendrina %s.",
     "{user} has shared the board %s with you." : "{user} pradėjo su jumis bendrinti plokštę %s.",
     "No data was provided to create an attachment." : "Priedo sukūrimui nebuvo pateikta jokių duomenų.",
     "Finished" : "Baigta",
     "To review" : "Reikia peržiūrėti",
     "Action needed" : "Reikalingas veiksmas",
     "Later" : "Vėliau",
+    "copy" : "kopija",
     "To do" : "Reikia atlikti",
     "Doing" : "Atliekama",
     "Done" : "Atlikta",
@@ -98,86 +94,117 @@ OC.L10N.register(
     "Could not write file to disk" : "Nepavyko įrašyti failą į diską",
     "A PHP extension stopped the file upload" : "PHP plėtinys sustabdė failo įkėlimą",
     "No file uploaded or file size exceeds maximum of %s" : "Neįkeltas joks failas arba failo dydis viršija maksimalų %s dydį",
-    "Add a new stack" : "Pridėti naują dėklą",
-    "Submit" : "Pateikti",
-    "Show archived cards" : "Rodyti archyvuotas korteles",
-    "Hide archived cards" : "Slėpti archyvuotas korteles",
-    "Toggle compact mode" : "Perjungti kompaktišką veikseną",
-    "Show board details" : "Rodyti išsamesnę plokštės informaciją",
-    "All Boards" : "Visos plokštės",
-    "Archived boards" : "Archyvuotos plokštės",
-    "Share board" : "Bendrinti plokštę",
+    "Personal planning and team project organization" : "Asmeninis planavimas ir komandinių projektų organizavimas",
+    "Create new board" : "Sukurti naują lentą",
+    "new board" : "nauja lenta",
+    "Select the board to link to a project" : "Pasirinkite lentą, kurią susieti su projektu",
+    "Select board" : "Pasirinkti lentą",
+    "Select the card to link to a project" : "Pasirinkite kortelę, kurią susieti su projektu",
+    "Select a board" : "Pasirinkite lentą",
+    "Select a card" : "Pasirinkti kortelę",
+    "Link to card" : "Susieti su kortele",
+    "Cancel" : "Atsisakyti",
+    "File already exists" : "Failas jau yra",
+    "A file with the name {filename} already exists." : "Failas, pavadinimu {filename}, jau yra.",
+    "Do you want to overwrite it?" : "Ar norite jį perrašyti?",
+    "Overwrite file" : "Perrašyti failą",
+    "Keep existing file" : "Palikti esamą failą",
+    "This board is read only" : "Ši plokštė yra tik skaitymui",
     "Archived cards" : "Archyvuotos kortelės",
-    "Actions" : "Veiksmai",
-    "Drop your files here to upload it to the card" : "Vilkite savo failus čia, norėdami įkelti juos į kortelę",
-    "Assign card to me" : "Priskirti kortelę sau",
-    "Archive card" : "Archyvuoti kortelę",
-    "Unarchive card" : "Išarchyvuoti kortelę",
-    "Delete card" : "Ištrinti kortelę",
-    "Enter a card title" : "Įveskite kortelės pavadinimą",
-    "Add card" : "Pridėti kortelę",
-    "Close" : "Užverti",
+    "Add new list" : "Pridėti naują sąrašą",
+    "List name" : "Sąrašo pavadinimas",
+    "Apply filter" : "Taikyti filtrą",
+    "Filter by tag" : "Filtruoti pagal žymę",
+    "Filter by assigned user" : "Filtruoti pagal priskirtą naudotoją",
+    "Filter by due date" : "Filtruoti pagal galutinio termino datą",
+    "Overdue" : "Praėjęs galutinis terminas",
+    "Next 24 hours" : "Artimiausios 24 val.",
+    "Next 7 days" : "Artimiausios 7 dienos",
+    "Next 30 days" : "Artimiausios 30 dienų",
+    "No due date" : "Be galutinio termino",
+    "Show archived cards" : "Rodyti archyvuotas korteles",
+    "Toggle compact mode" : "Perjungti kompaktišką veikseną",
+    "Details" : "Išsamiau",
+    "Loading board" : "Įkeliama lenta",
+    "Board not found" : "Lenta nerasta",
     "Sharing" : "Bendrinimas",
     "Tags" : "Žymės",
     "Deleted items" : "Ištrinti elementai",
-    "Select users or groups to share with" : "Pasirinkti naudotojus ar grupes su kuriomis bendrinti",
-    "Group" : "Grupė",
-    "Circle" : "Ratas",
-    "No matching user or group found." : "Nerasta vartotojų ir grupių",
-    "Loading" : "Įkeliama",
-    "Edit" : "Taisyti",
-    "Share" : "Bendrinti",
-    "Manage" : "Tvarkyti",
-    "Sharing has been disabled for your account." : "Bendrinimas yra išjungtas jūsų paskyrai.",
-    "Update tag" : "Atnaujinti žymę",
-    "Edit tag" : "Taisyti žymę",
-    "Delete tag" : "Ištrinti žymę",
-    "Create" : "Sukurti",
-    "Create a new tag" : "Sukurti naują žymę",
-    "Deleted stacks" : "Ištrinti dėklai",
+    "Timeline" : "Laiko juosta",
+    "Deleted lists" : "Ištrinti sąrašai",
+    "Undo" : "Atšaukti",
     "Deleted cards" : "Ištrintos kortelės",
-    "Status" : "Būsena",
-    "Title" : "Pavadinimas",
-    "Members" : "Nariai",
-    "More actions" : "Daugiau veiksmų",
-    "Edit board" : "Taisyti plokštę",
-    "Archive board" : "Archyvuoti plokštę",
-    "Unarchive board" : "Išarchyvuoti plokštę",
-    "Delete board" : "Ištrinti plokštę",
-    "Update board" : "Atnaujinti plokštę",
-    "Reset board" : "Atstatyti plokštę",
-    "Undo board deletion - Otherwise the board will be deleted during the next cronjob run." : "Atšaukti plokštės ištrynimą - Priešingu atveju, plokštė bus ištrinta kitos cron užduoties vykdymo metu.",
-    "Create new board" : "Sukurti naują plokštę",
-    "New board title" : "Naujos plokštės pavadinimas",
-    "Create board" : "Sukurti plokštę",
-    "Cancel upload" : "Atsisakyti įkėlimo",
-    "by" : "pagal",
-    "Undo file deletion - Otherwise the file will be deleted during the next cronjob run." : "Atšaukti failo ištrynimą - Priešingu atveju, failas bus ištrintas kitos cron užduoties vykdymo metu.",
-    "Undo file deletion" : "Atšaukti failo ištrynimą",
-    "Insert the file into the description" : "Įterpti failą į aprašą",
-    "Delete attachment" : "Ištrinti priedą",
-    "Modified:" : "Keitimo laikas:",
-    "Created:" : "Sukūrimo laikas:",
-    "Choose a tag" : "Pasirinkite žymę",
-    "Add a tag" : "Pridėti žymę",
-    "Select tags" : "Pasirinkti žymes",
-    "Assign users" : "Priskirti naudotojus",
-    "Choose a user to assign" : "Pasirinkite naudotoją, kuriam priskirti",
-    "Assign this card to a user" : "Priskirti šią kortelę naudotojui",
+    "Share board with a user, group or circle …" : "Bendrinti lentą su naudotoju, grupe ar ratu…",
+    "Board owner" : "Lentos savininkas",
+    "(Group)" : "(Grupė)",
+    "(Circle)" : "(Ratas)",
+    "Can edit" : "Gali redaguoti",
+    "Can share" : "Can share",
+    "Can manage" : "Gali tvarkyti",
+    "Delete" : "Ištrinti",
+    "Add a new stack" : "Pridėti naują dėklą",
+    "Delete list" : "Ištrinti sąrašą",
+    "Add card" : "Pridėti kortelę",
+    "Add a new card" : "Pridėti naują kortelę",
+    "Edit" : "Taisyti",
+    "Add a new tag" : "Pridėti naują žymę",
+    "title and color value must be provided" : "privalo būti pateiktos pavadinimo ir spalvos reikšmės",
+    "Add this attachment" : "Pridėti šį priedą",
+    "Delete Attachment" : "Ištrinti priedą",
+    "Restore Attachment" : "Atkurti priedą",
+    "Assign a tag to this card…" : "Priskirti šiai kortelei žymę…",
+    "Assign to users" : "Priskirti naudotojams",
+    "Assign to users/groups/circles" : "Priskirti naudotojams/grupėms/ratams",
+    "Assign a user to this card…" : "Priskirti šiai kortelei naudotoją…",
     "Due date" : "Terminas",
-    "Click to set" : "Spustelėkite pakeitimams atlikti",
+    "Set a due date" : "Nustatyti galutinį terminą",
     "Remove due date" : "Pašalinti terminą",
     "Description" : "Aprašas",
-    "Attachments" : "Priedai",
-    "Saved" : "Įrašyta",
-    "Unsaved changes" : "Neįrašyti pakeitimai",
-    "Insert attachment" : "Įterpti priedą",
+    "(Unsaved)" : "(Neįrašyta)",
+    "(Saving…)" : "(Įrašoma…)",
     "Formatting help" : "Formatavimo pagalba",
+    "Add Attachment" : "Pridėti priedą",
+    "Edit description" : "Taisyti aprašą",
+    "View description" : "Rodyti aprašą",
+    "Attachments" : "Priedai",
+    "Comments" : "Komentarai",
+    "Choose attachment" : "Pasirinkite priedą",
+    "Modified" : "Pakeistas",
+    "Created" : "Sukurta",
     "Upload attachment" : "Įkelti priedą",
-    "Add a card description…" : "Pridėti kortelės aprašą...",
-    "Shared boards" : "Bendrinamos plokštės",
-    "Move board to archive" : "Perkelti plokštę į archyvą",
-    "Create a new board" : "Sukurti naują plokštę",
-    "Settings" : "Nustatymai"
+    "No comments yet. Begin the discussion!" : "Kol kas komentarų nėra. Pradėkite diskusiją!",
+    "Save" : "Įrašyti",
+    "The comment cannot be empty." : "Komentaras negali būti tuščias.",
+    "The comment cannot be longer than 1000 characters." : "Komentaras negali būti ilgesnis nei 1000 simbolių.",
+    "Reply" : "Atsakyti",
+    "Update" : "Atnaujinti",
+    "(group)" : "(grupė)",
+    "(circle)" : "(ratas)",
+    "Assign to me" : "Priskirti sau",
+    "Delete card" : "Ištrinti kortelę",
+    "Move card" : "Perkelti kortelę",
+    "Card details" : "Išsamiau apie kortelę",
+    "Select a stack" : "Pasirinkti dėklą",
+    "seconds ago" : "prieš keletą sekundžių",
+    "All boards" : "Visos lentos",
+    "Archived boards" : "Archyvuotos lentos",
+    "Shared boards" : "Bendrinamos lentos",
+    "Settings" : "Nustatymai",
+    "New board title" : "Naujos lentos pavadinimas",
+    "Share" : "Bendrinti",
+    "Options" : "Parinktys",
+    "Edit board" : "Taisyti lentą",
+    "An error occurred" : "Įvyko klaida",
+    "Clone board" : "Dubliuoti lentą",
+    "Archive board" : "Archyvuoti lentą",
+    "Unarchive board" : "Išarchyvuoti lentą",
+    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Ar tikrai norite ištrinti plokštę, pavadinimu {title}? Tai ištrins visus šios plokštės duomenis.",
+    "Delete the board?" : "Ištrinti plokštę?",
+    "Delete board" : "Ištrinti lentą",
+    "Board details" : "Išsamiau apie lentą",
+    "Link to a board" : "Susieti su lenta",
+    "Link to a card" : "Susieti su kortele",
+    "Something went wrong" : "Kažkas nutiko",
+    "Maximum file size of {size} exceeded" : "Viršytas maksimalus {size} failo dydis"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
