@@ -6,18 +6,16 @@ OC.L10N.register(
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Saiz fail yang dimuatnaik melebihi MAX_FILE_SIZE yang ditetapkan dalam borang HTML",
     "No file was uploaded" : "Tiada fail dimuatnaik",
     "Missing a temporary folder" : "Direktori sementara hilang",
-    "Close" : "Tutup",
-    "Group" : "Group",
-    "Loading" : "Loading",
+    "Cancel" : "Batal",
+    "Can edit" : "Can edit",
+    "Can share" : "Can share",
+    "Delete" : "Padam",
     "Edit" : "Sunting",
-    "Share" : "Kongsi",
-    "Create" : "Buat",
-    "Title" : "Judul",
-    "Cancel upload" : "Batal muat naik",
-    "by" : "oleh",
-    "Modified:" : "Telah diubah:",
-    "Created:" : "Telah dibina:",
     "Description" : "Keterangan",
-    "Settings" : "Tetapan"
+    "Modified" : "Dimodifikasi",
+    "Save" : "Simpan",
+    "Update" : "Kemaskini",
+    "Settings" : "Tetapan",
+    "Share" : "Kongsi"
 },
 "nplurals=1; plural=0;");
