@@ -6,23 +6,22 @@ OC.L10N.register(
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den opplasta fila er større enn variabelen MAX_FILE_SIZE i HTML-skjemaet",
     "No file was uploaded" : "Ingen filer vart lasta opp",
     "Missing a temporary folder" : "Manglar ei mellombels mappe",
-    "Actions" : "Handlingar",
-    "Close" : "Lukk",
+    "Cancel" : "Avbryt",
+    "Details" : "Detaljar",
     "Sharing" : "Deling",
     "Tags" : "Emneord",
-    "Group" : "Gruppe",
-    "Loading" : "Loading",
+    "Can edit" : "Can edit",
+    "Can share" : "Can share",
+    "Delete" : "Ta bort",
     "Edit" : "Endra",
-    "Share" : "Del",
-    "Create" : "Lag",
-    "Status" : "Status",
-    "Title" : "Tittel",
-    "Cancel upload" : "Avbryt opplasting",
-    "by" : "av",
-    "Modified:" : "Endra:",
-    "Created:" : "Oppretta:",
     "Description" : "Skildring",
-    "Saved" : "Lagra",
-    "Settings" : "Instillingar"
+    "Comments" : "Kommentarar",
+    "Modified" : "Endra",
+    "Created" : "Lagd",
+    "Save" : "Lagre",
+    "Update" : "Oppdater",
+    "seconds ago" : "sekund sidan",
+    "Settings" : "Instillingar",
+    "Share" : "Del"
 },
 "nplurals=2; plural=(n != 1);");
