@@ -1,10 +1,6 @@
 OC.L10N.register(
     "deck",
     {
-    "Remove user from card" : "Remover utilizador do cartão",
-    "Hours" : "Horas",
-    "Minutes" : "Minutos",
-    "File already exists" : "O ficheiro já existe",
     "Deck" : "Baralho",
     "Personal" : "Pessoal",
     "The card \"%s\" on \"%s\" has reached its due date." : "O cartão \"%s\" em \"%s\" chegou a sua data de vencimento",
@@ -14,57 +10,47 @@ OC.L10N.register(
     "To review" : "A rever",
     "Action needed" : "Acção necessária",
     "Later" : "Mais tarde",
+    "copy" : "copiar",
     "Done" : "Concluído",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O ficheiro carregado excede a directiva upload_max_filesize no php.ini ",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O ficheiro carregado excedo a directiva MAX_FILE_SIZE especificada no formulário HTML",
     "No file was uploaded" : "O ficheiro foi carregado",
     "Missing a temporary folder" : "Falta uma pasta temporária",
-    "Add a new stack" : "Adicionar nova pilha",
-    "Submit" : "Submeter",
+    "Create new board" : "Criar novo quadro",
+    "Cancel" : "Cancelar",
+    "File already exists" : "O ficheiro já existe",
     "Show archived cards" : "Mostrar cartões arquivados",
-    "Hide archived cards" : "Esconder cartões arquivados",
-    "All Boards" : "Todos os quadros",
-    "Archived boards" : "Quadros arquivados",
-    "Actions" : "Ações",
-    "Archive card" : "Arquivar cartão",
-    "Delete card" : "Eliminar cartão",
-    "Enter a card title" : "Insira um título para o cartão",
-    "Add card" : "Adicionar um cartão",
-    "Close" : "Fechar",
+    "Details" : "Detalhes",
     "Sharing" : "Partilha",
     "Tags" : "Etiquetas",
-    "Select users or groups to share with" : "Seleccionar utilizadores ou grupos para partilhar com",
-    "Group" : "Grupo",
-    "Circle" : "Círculo",
-    "Loading" : "A carregar",
+    "Undo" : "Desfazer",
+    "(Group)" : "(Grupo)",
+    "Can edit" : "Can edit",
+    "Can share" : "Can share",
+    "Delete" : "Apagar",
+    "Add a new stack" : "Adicionar nova pilha",
+    "Add card" : "Adicionar um cartão",
     "Edit" : "Editar",
-    "Share" : "Partilhar",
-    "Manage" : "Gerir",
-    "Create" : "Criar",
-    "Create a new tag" : "Criar uma nova etiqueta",
-    "Status" : "Estado",
-    "Title" : "Título ",
-    "Members" : "Membros",
-    "More actions" : "Mais acções",
-    "Edit board" : "Editar quadro",
-    "Archive board" : "Arquivar quadro",
-    "Delete board" : "Eliminar quadro",
-    "Create new board" : "Criar novo quadro",
-    "New board title" : "Novo título de quadro",
-    "Create board" : "Criar quadro",
-    "Cancel upload" : "Cancelar envio",
-    "by" : "por",
-    "Modified:" : "Modificado:",
-    "Created:" : "Criado:",
-    "Choose a tag" : "Escolher etiqueta",
-    "Add a tag" : "Adicionar uma etiqueta",
-    "Assign users" : "Atribuir utilizadores",
     "Due date" : "Data limite",
     "Description" : "Descrição",
     "Attachments" : "Anexos",
-    "Saved" : "Guardado",
-    "Unsaved changes" : "Modificações não guardadas",
-    "Create a new board" : "Criar um novo quadro",
-    "Settings" : "Definições"
+    "Comments" : "Comentários",
+    "Modified" : "Modificado",
+    "Created" : "Criado",
+    "Save" : "Guardar",
+    "Reply" : "Resposta",
+    "Update" : "Atualizar",
+    "(group)" : "(grupo)",
+    "Delete card" : "Eliminar cartão",
+    "seconds ago" : "segundos atrás",
+    "Archived boards" : "Quadros arquivados",
+    "Settings" : "Definições",
+    "New board title" : "Novo título de quadro",
+    "Share" : "Partilhar",
+    "Edit board" : "Editar quadro",
+    "An error occurred" : "Ocorreu um erro",
+    "Archive board" : "Arquivar quadro",
+    "Delete board" : "Eliminar quadro",
+    "Board details" : "Detalhes do quadro"
 },
 "nplurals=2; plural=(n != 1);");
