@@ -1,35 +1,32 @@
 OC.L10N.register(
     "deck",
     {
-    "Hours" : "Ore",
-    "Minutes" : "Minute",
-    "File already exists" : "Fișierul există deja",
     "Personal" : "Personal",
     "Finished" : "Finalizat",
+    "copy" : "copiază",
     "Done" : "Realizat",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Fișierul încărcat depășește directiva MAX_FILE_SIZE specificată în formularul HTML",
     "No file was uploaded" : "Nu a fost încărcat niciun fișier",
     "Missing a temporary folder" : "Lipsește un dosar temporar",
-    "Submit" : "Trimite",
-    "Actions" : "Acțiuni",
-    "Close" : "Închide",
+    "Cancel" : "Anulează",
+    "File already exists" : "Fișierul există deja",
+    "Details" : "Detalii",
     "Sharing" : "Partajare",
     "Tags" : "Etichete",
-    "Group" : "Grup",
-    "Circle" : "Cerc",
-    "Loading" : "Loading",
+    "Undo" : "Anulează ultima acțiune",
+    "Can edit" : "Poate edita",
+    "Can share" : "Can share",
+    "Delete" : "Șterge",
     "Edit" : "Editează",
-    "Share" : "Partajează",
-    "Create" : "Creează",
-    "Status" : "Stare",
-    "Title" : "Titlu",
-    "Cancel upload" : "Anulează încărcarea",
-    "by" : "de",
-    "Modified:" : "Modificat:",
-    "Created:" : "Creat:",
     "Description" : "Descriere",
-    "Saved" : "Salvat",
-    "Unsaved changes" : "Modificări nesalvate",
-    "Settings" : "Setări"
+    "Comments" : "Comentarii",
+    "Modified" : "Modificat",
+    "Save" : "Salvează",
+    "Reply" : "Răspunde",
+    "Update" : "Actualizare",
+    "(group)" : "(grup)",
+    "seconds ago" : "secunde în urmă",
+    "Settings" : "Setări",
+    "Share" : "Partajează"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
