@@ -6,20 +6,20 @@ OC.L10N.register(
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "උඩුගත කළ ගොනුවේ විශාලත්වය HTML පෝරමයේ නියම කළ ඇති MAX_FILE_SIZE විශාලත්වයට වඩා වැඩිය",
     "No file was uploaded" : "ගොනුවක් උඩුගත නොවුණි",
     "Missing a temporary folder" : "තාවකාලික ෆොල්ඩරයක් අතුරුදහන්",
-    "Close" : "වසන්න",
+    "Cancel" : "අවලංගු කරන්න",
     "Sharing" : "හුවමාරු කිරීම",
     "Tags" : "ටැග",
-    "Group" : "Group",
-    "Loading" : "Loading",
+    "Can edit" : "Can edit",
+    "Can share" : "Can share",
+    "Delete" : "ඉවත් කරන්න",
     "Edit" : "සකසන්න",
-    "Share" : "බෙදා හදා ගන්න",
-    "Create" : "තනන්න",
-    "Title" : "මාතෘකාව",
-    "Cancel upload" : "උඩුගත කිරීම අත් හරින්න",
-    "by" : "විසින්",
-    "Modified:" : "වෙනස් කළ දිනය:",
-    "Created:" : "සෑදු දිනය:",
     "Description" : "විස්තරය",
-    "Settings" : "සැකසුම්"
+    "Comments" : "අදහස්",
+    "Modified" : "වෙනස් කළ",
+    "Save" : "සුරකින්න",
+    "Update" : "යාවත්කාල කිරීම",
+    "seconds ago" : "තත්පරයන්ට පෙර",
+    "Settings" : "සැකසුම්",
+    "Share" : "බෙදා හදා ගන්න"
 },
 "nplurals=2; plural=(n != 1);");
