@@ -1,17 +1,6 @@
 OC.L10N.register(
     "deck",
     {
-    "Please provide a content for your comment." : "Zadajte obsah svojho komentára",
-    "Posting the comment failed." : "Nepodarilo sa odoslať komentár",
-    "The comment has been deleted" : "Komentár bol odstránený",
-    "The associated stack is deleted as well, it will be restored as well." : "Súvisiaci stoh je tiež odstránený a bude tiež obnovený",
-    "Restore associated stack" : "Obnoviť súvisiaci stoh",
-    "Remove user from card" : "Odobrať používateľa z karty",
-    "Hours" : "Hodín",
-    "Minutes" : "Minút",
-    "Link to a board" : "Odkaz na nástenku",
-    "Maximum file size of {size} exceeded" : "Bola prekročená maximálna veľkosť súboru {size}",
-    "File already exists" : "Súbor už existuje",
     "You have created a new board {board}" : "Vytvorili ste nová nástenku {board}",
     "{user} has created a new board {board}" : "Používateľ {user} vytvoril novú nástenku {board}",
     "You have deleted the board {board}" : "Vymazali ste nástenku {board}",
@@ -91,6 +80,7 @@ OC.L10N.register(
     "To review" : "Na posúdenie",
     "Action needed" : "Potrebná akcia",
     "Later" : "Neskôr",
+    "copy" : "kopírovať",
     "To do" : "Urobiť",
     "Doing" : "Prebieha",
     "Done" : "Hotové",
@@ -106,98 +96,122 @@ OC.L10N.register(
     "Could not write file to disk" : "Nepodarilo sa zapísať súbor na disk",
     "A PHP extension stopped the file upload" : "Rozšírenie PHP zastavilo nahrávanie súboru",
     "No file uploaded or file size exceeds maximum of %s" : "Nenahral sa žiadny súbor alebo jeho veľkosť presiahla %s",
-    "A kanban style project and personal management tool for Nextcloud" : "Nástroj pre projektové a osobné riadenie v štýle Kanban.",
+    "Personal planning and team project organization" : "Osobné plánovanie a organizácia tímových projektov",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Karty sú nástroj zacielený na osobné alebo projektové plánovanie tímov v štýle Kanban integrovaný do Nextcloud.\n\n\n- 📥 Zadávajte a usporadúvajte svoje úlohy do kariet\n- 📄 Zapisujte si dodatočné poznámky\n- 🔖 Priraďujte štítky pre ešte lepšiu organizáciu\n- 👥 Zdieľajte so svojim tímom, priateľmi alebo rodinou\n- 🚀 Dostaňte svoj projekt pod kontrolu",
+    "Create new board" : "Vytvoriť novú nástenku",
+    "new board" : "nová nástenka",
     "Select the board to link to a project" : "Vybrať nástenku na vytvorenie odkazu ku projektu",
     "Select board" : "Vybrať nástenku",
-    "Add a new stack" : "Pridať nový stoh",
-    "Submit" : "Odoslať",
-    "Show archived cards" : "Zobraziť archivované karty",
-    "Hide archived cards" : "Skryť archivované karty",
-    "Toggle compact mode" : "Vyp/zap. kompaktný režim",
-    "Show board details" : "Zobraziť podrobnosti o nástenke",
-    "All Boards" : "Všetky nástenky",
-    "Archived boards" : "Archivované nástenky",
-    "Share board" : "Zdieľať nástenku",
+    "Select the card to link to a project" : "Vyberte kartu, ktorú chcete prepojiť s projektom",
+    "Select a board" : "Vyberte nástenku",
+    "Select a card" : "Vyberte kartu",
+    "Link to card" : "Prepojiť s kartou",
+    "Cancel" : "Zrušiť",
+    "File already exists" : "Súbor už existuje",
+    "A file with the name {filename} already exists." : "Súbor s názvom {filename} už existuje.",
+    "Do you want to overwrite it?" : "Chcete ho prepísať?",
+    "Overwrite file" : "Prepísať súbor",
+    "Keep existing file" : "Ponechať existujúci súbor",
+    "This board is read only" : "Táto nástenka je iba na čítanie",
+    "Drop your files to upload" : "Pretiahnite sem súbory, ktoré chcete nahrať",
     "Archived cards" : "Archivované karty",
-    "Actions" : "Akcie",
-    "Drop your files here to upload it to the card" : "Tu vložte svoje súbory ak ich chcete pripojiť ku karte.",
-    "Assign card to me" : "Priradiť kartu mne",
-    "Unassign card from me" : "Zrušiť priradenie karty mne",
-    "Archive card" : "Archivovať kartu",
-    "Unarchive card" : "Zrušiť archiváciu karty",
-    "Delete card" : "Zmazať kartu",
-    "Enter a card title" : "Zmeniť názov karty",
-    "Add card" : "Pridať kartu",
-    "Close" : "Zavrieť",
+    "Add new list" : "Pridať nový zoznam",
+    "List name" : "Názov zoznamu",
+    "Apply filter" : "Uplatniť filter",
+    "Filter by tag" : "Filtrovať podľa štítkov",
+    "Filter by assigned user" : "Filtrovať podľa priradeného používateľa",
+    "Filter by due date" : "Filtrovať podľa termínu",
+    "Overdue" : "Po termíne",
+    "Next 24 hours" : "Ďalších 24 hodín",
+    "Next 7 days" : "Následujúcich 7 dní",
+    "Next 30 days" : "Následujúcich 30 dní",
+    "No due date" : "Bez termínu",
+    "Show archived cards" : "Zobraziť archivované karty",
+    "Toggle compact mode" : "Vyp/zap. kompaktný režim",
+    "Details" : "Podrobnosti",
+    "Loading board" : "Načítanie nástenky",
+    "Board not found" : "Nástenka nebola nájdená",
     "Sharing" : "Sprístupnenie",
     "Tags" : "Štítky",
     "Deleted items" : "Zmazané položky",
     "Timeline" : "Časová os",
-    "Select users or groups to share with" : "Vyberte používateľov albo skupiny pre sprístupnenie",
-    "Group" : "Skupina",
-    "Circle" : "Kruh",
-    "No matching user or group found." : "Neboli nájdení vyhovujúci používatelia alebo skupiny.",
-    "Loading" : "Načítavanie",
-    "Edit" : "Upraviť",
-    "Share" : "Sprístupniť",
-    "Manage" : "Spravovať",
-    "Discard share" : "Zrušiť sprístupnenie",
-    "Sharing has been disabled for your account." : "Sprístupňovanie bolo pre vaše konto zakázané.",
-    "Update tag" : "Aktualizovať štítok",
-    "Edit tag" : "Upraviť štítok",
-    "Delete tag" : "Zmazať štítok",
-    "Create" : "Vytvoriť",
-    "Create a new tag" : "Vytvoriť nový štítok",
-    "Deleted stacks" : "Odstránené stohy",
+    "Deleted lists" : "Vymazané zoznamy",
+    "Undo" : "Odvolať",
     "Deleted cards" : "Odstránené karty",
-    "Status" : "Stav",
-    "No archived boards to display" : "Žiadne archivované nástenky",
-    "No shared boards to display" : "Žiadne sprístupnené nástenky",
-    "Title" : "Názov",
-    "Members" : "Členovia",
-    "More actions" : "Viac akcií",
-    "Edit board" : "Upraviť nástenku",
-    "Archive board" : "Archivovať nástenku",
-    "Unarchive board" : "Vybrať nástenku z archívu",
-    "Delete board" : "Zmazať nástenku",
-    "Update board" : "Aktualizovať nástenku",
-    "Reset board" : "Resetovať nástenku",
-    "Undo board deletion - Otherwise the board will be deleted during the next cronjob run." : "Vrátiť späť vymazanie nástenky - v opačnom prípade bude nástenka vymazaná počas ďalšieho behu úlohy cronjob.",
-    "Create new board" : "Vytvoriť novú nástenku",
-    "New board title" : "Názov novej nástenky",
-    "Create board" : "Vytvoriť nástenku",
-    "Select an attachment" : "Vybrať prílohu",
-    "Cancel upload" : "Zrušiť nahrávanie",
-    "by" : "-",
-    "Undo file deletion - Otherwise the file will be deleted during the next cronjob run." : "Vrátiť späť zmazanie súboru - v opačnom prípade bude súbor vymazaný počas ďalšieho behu úlohy cronjob.",
-    "Undo file deletion" : "Vrátiť späť odstránenie súboru",
-    "Insert the file into the description" : "Vložte súbor do popisu",
-    "Delete attachment" : "Zmazať prílohu",
-    "Modified:" : "Upravené:",
-    "Created:" : "Vytvorené:",
-    "Choose a tag" : "Vybrať štítok",
-    "Add a tag" : "Pridať štítok",
-    "Select tags" : "Zvoliť štítky",
-    "Assign users" : "Priradiť používateľov",
-    "Choose a user to assign" : "Vyberte používateľa, ktorého chcete priradiť",
-    "Assign this card to a user" : "Priradiť túto kartu používateľovi",
+    "Share board with a user, group or circle …" : "Zdieľanie nástenky s použivateľom, skupinou alebo okruhom…",
+    "Board owner" : "Vlastník nástenky",
+    "(Group)" : "(Skupina)",
+    "(Circle)" : "(Okruh)",
+    "Can edit" : "Môže upravovať",
+    "Can share" : "Môže sprístupniť",
+    "Can manage" : "Môže spravovať",
+    "Delete" : "Zmazať",
+    "Add a new stack" : "Pridať nový stoh",
+    "Delete list" : "Vymazať zoznam",
+    "Add card" : "Pridať kartu",
+    "Add a new card" : "Pridať novú kartu",
+    "Edit" : "Upraviť",
+    "Add a new tag" : "Pridať nový štítok",
+    "title and color value must be provided" : "je potrebné zadať nadpis a vybrať farbu",
+    "Add this attachment" : "Pridať túto prílohu",
+    "Delete Attachment" : "Odstrániť prílohu",
+    "Restore Attachment" : "Obnoviť prílohu",
+    "Assign a tag to this card…" : "Tejto karte priradiť štítok…",
+    "Assign to users" : "Priradiť používateľom",
+    "Assign to users/groups/circles" : "Priradiť používateľom/skupinám/okruhom",
+    "Assign a user to this card…" : "Priradiť používateľa k tejto karte…",
     "Due date" : "Termín dokončenia",
-    "Click to set" : "Kliknite pre nastavenie",
+    "Set a due date" : "Nastaviť termín",
     "Remove due date" : "Odstrániť termín dokončenia",
     "Description" : "Popis",
-    "Attachments" : "Prílohy",
-    "Saved" : "Uložené",
-    "Unsaved changes" : "Neuložené zmeny",
-    "Insert attachment" : "Vložiť prílohu",
+    "(Unsaved)" : "(Neuložené)",
+    "(Saving…)" : "(Ukladanie…)",
     "Formatting help" : "Pomoc pri formátovaní",
+    "Add Attachment" : "Pridať prílohu",
+    "Edit description" : "Upraviť popis",
+    "View description" : "Zobraziť popis",
+    "Attachments" : "Prílohy",
+    "Comments" : "Komentáre",
+    "Choose attachment" : "Vybrať prílohu",
+    "Modified" : "Upravené",
+    "Created" : "Vytvorené",
     "Upload attachment" : "Nahrať prílohu",
-    "Add a card description…" : "Pridať popis karty...",
+    "No comments yet. Begin the discussion!" : "Zatiaľ bez komentárov. Začnite diskusiu!",
+    "Save" : "Uložiť",
+    "The comment cannot be empty." : "Komentár nemôže byť prázdny.",
+    "The comment cannot be longer than 1000 characters." : "Komentár nemôže byť dlhší ako 1000 znakov.",
+    "In reply to" : "Odpoveď na",
+    "Reply" : "Odpoveď",
+    "Update" : "Aktualizovať",
+    "(group)" : "(skupina)",
+    "(circle)" : "(okruh)",
+    "Assign to me" : "Priradiť mne",
+    "Delete card" : "Zmazať kartu",
+    "Move card" : "Presunúť kartu",
+    "Card details" : "Podrobnosti o karte",
+    "Select a stack" : "Vybrať stĺpec",
+    "seconds ago" : "pred niekoľkými sekundami",
+    "All boards" : "Všetky nástenky",
+    "Archived boards" : "Archivované nástenky",
     "Shared boards" : "Sprístupnené nástenky",
-    "Move board to archive" : "Presunúť nástenku do archívu",
-    "Create a new board" : "Vytvoriť novú nástenku",
     "Settings" : "Nastavenia",
-    "Limit deck to groups" : "Obmedziť nástenku pre skupiny",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Obmedzenie Násteniek bráni používateľom, ktorí nie sú súčasťou týchto skupín, aby si vytvárali vlastné nástenky. Môžu však stále pracovať na nástenkách, ktoré im niekto sprístupní."
+    "Limit deck usage of groups" : "Obmedziť použitie Deck na skupiny",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Obmedzenie Násteniek bráni používateľom, ktorí nie sú súčasťou týchto skupín, aby si vytvárali vlastné nástenky. Môžu však stále pracovať na nástenkách, ktoré im niekto sprístupní.",
+    "New board title" : "Názov novej nástenky",
+    "Share" : "Sprístupňovať",
+    "Options" : "Možnosti",
+    "Edit board" : "Upraviť nástenku",
+    "An error occurred" : "Vyskytla sa chyba",
+    "Clone board" : "Duplikovať nástenku",
+    "Archive board" : "Archivovať nástenku",
+    "Unarchive board" : "Vybrať nástenku z archívu",
+    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Naozaj chcete chcete vymazať nástenku {title}? Toto zmaže všetky údaje o tejto nástenke.",
+    "Delete the board?" : "Vymazať nástenku?",
+    "Delete board" : "Zmazať nástenku",
+    "Board details" : "Podrobnosti o nástenke",
+    "Link to a board" : "Odkaz na nástenku",
+    "Link to a card" : "Prepojiť s kartou",
+    "Something went wrong" : "Niečo sa pokazilo",
+    "Maximum file size of {size} exceeded" : "Bola prekročená maximálna veľkosť súboru {size}"
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
