@@ -1,17 +1,6 @@
 OC.L10N.register(
     "deck",
     {
-    "Please provide a content for your comment." : "Vpišite vsebino opombe.",
-    "Posting the comment failed." : "Objava opombe je spodletela.",
-    "The comment has been deleted" : "Opomba je bila izbrisana",
-    "The associated stack is deleted as well, it will be restored as well." : "Povezan paket nalog, ki je bil prav tako izbrisan, bo tudi obnovljen.",
-    "Restore associated stack" : "Obnovi povezan paket nalog",
-    "Remove user from card" : "Odstrani uporabnika z naloge",
-    "Hours" : "Ura",
-    "Minutes" : "Minute",
-    "Link to a board" : "Povezava do zbirke",
-    "Maximum file size of {size} exceeded" : "Omejitev velikosti datoteke {size} je prekoračena.",
-    "File already exists" : "Datoteka že obstaja",
     "You have created a new board {board}" : "Ustvarite novo zbirko {board}",
     "{user} has created a new board {board}" : "Uporabnik {user} ustvari novo zbirko {board}",
     "You have deleted the board {board}" : "Izbrišete zbirko {board}",
@@ -67,7 +56,9 @@ OC.L10N.register(
     "You have added the attachment {attachment} to card {card}" : "Dodate prilogo {attachment} k nalogi {card}",
     "{user} has added the attachment {attachment} to card {card}" : "{user} doda prilogo {attachment} k nalogi {card}",
     "You have updated the attachment {attachment} on card {card}" : "Posodobite prilogo {attachment} v nalogi {card}",
+    "{user} has updated the attachment {attachment} on card {card}" : "{user} posodobi prilogo {attachment} v nalogi {card}",
     "You have deleted the attachment {attachment} from card {card}" : "Izbišete prilogo {attachment} v nalogi {card}",
+    "{user} has deleted the attachment {attachment} from card {card}" : "{user} izbriše prilogo {attachment} iz naloge {card}",
     "You have restored the attachment {attachment} to card {card}" : "Obnovite prilogo {attachment} k nalogi {card}",
     "{user} has restored the attachment {attachment} to card {card}" : "{user} obnovi prilogo {attachment} naloge {card}",
     "You have commented on card {card}" : "Vpišete opombo k nalogi {card}",
@@ -77,12 +68,17 @@ OC.L10N.register(
     "Changes in the <strong>Deck app</strong>" : "Spremembe v programu <strong>Deck</strong>",
     "A <strong>comment</strong> was created on a card" : "Nalogi je dodana nova <strong>opomba</strong>",
     "Personal" : "Osebno",
+    "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user} vam dodeli nalogo »%s« na »%s«.",
+    "The card \"%s\" on \"%s\" has reached its due date." : "Naloga »%s« na »%s« je dosegla datum preteka.",
+    "%s has mentioned you in a comment on \"%s\"." : "%s vas omeni v opombi na »%s«.",
+    "{user} has mentioned you in a comment on \"%s\"." : "{user} vas omeni v opombi na »%s«.",
     "{user} has shared the board %s with you." : "{user} vam omogoči souporabo zbirke %s.",
     "No data was provided to create an attachment." : "Ni podanih podatkov za ustvarjanje priloge.",
     "Finished" : "Končano",
     "To review" : "Za pregled",
     "Action needed" : "Čaka na odziv",
     "Later" : "Kasneje",
+    "copy" : "kopija",
     "To do" : "Prihajajoče naloge",
     "Doing" : "Naloge v teku",
     "Done" : "Končane naloge",
@@ -91,105 +87,116 @@ OC.L10N.register(
     "Example Task 1" : "Primer naloge 1",
     "The file was uploaded" : "Datoteka je uspešno poslana.",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Poslana datoteka presega določilo največje dovoljene velikosti v datoteki php.ini",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Poslana datoteka presega velikost, ki jo določa parameter največje dovoljene velikosti MAX_FILE_SIZE v zapisu HTML.",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Poslana datoteka presega velikost, ki je določena kot omejitev MAX_FILE_SIZE v zapisu HTML.",
     "The file was only partially uploaded" : "Datoteka ni bila poslana v celoti",
     "No file was uploaded" : "Datoteka ni bila poslana",
     "Missing a temporary folder" : "Manjka začasna mapa",
     "Could not write file to disk" : "Ni mogoče zapisati datoteke na disk",
     "A PHP extension stopped the file upload" : "Razširitev PHP onemogoča pošiljanje datoteke",
     "No file uploaded or file size exceeds maximum of %s" : "Ali ni poslane datoteke ali pa velikost datoteke presega omejitev %s",
-    "A kanban style project and personal management tool for Nextcloud" : "Orodje za projektno in osebno vodenje nalog v slogu kanban za okolje Nextcloud.",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Program Deck je orodje za osebno načrtovanje in projektno delo v slogu kanban, ki se izvrstno vključuje v okolje Nextcloud.\n\nOrodje omogoča:\n- 📥 dodajanje in urejanje nalog\n- 📄 zapis dodatnih opomb v zapisu markdown\n- 🔖 dodeljevanje oznak za lažje urejanje in iskanje\n- 👥 souporabo v skupini, s prijatelji ali družino\n- 📎 pripenjanje in vstavljanje datotek v opise\n- 💬 opombe k posamezni nalogi\n- ⚡ sledenje spremembam in dejavnosti\n- 🚀 Organizaciji projekta",
+    "Create new board" : "Ustvari novo zbirko",
+    "new board" : "nova zbirka",
     "Select the board to link to a project" : "Izberite zbirko za povezavo s projektom",
     "Select board" : "Izbor zbirke",
-    "Add a new stack" : "Dodaj nov paket nalog",
-    "Submit" : "Objavi",
-    "Show archived cards" : "Prikaži arhivirane naloge",
-    "Hide archived cards" : "Skrij arhivirane naloge",
-    "Toggle compact mode" : "Preklopi način prikaza",
-    "Show board details" : "Pokaži podrobnosti zbirke",
-    "All Boards" : "Vse zbirke",
-    "Archived boards" : "Arhivirane zbirke",
-    "Share board" : "Souporaba zbirke",
+    "Select the card to link to a project" : "Izbor naloge za povezavo do projekta",
+    "Select a board" : "Izbor zbirke",
+    "Select a card" : "Izbor naloge",
+    "Link to card" : "Poveži nalogo",
+    "Cancel" : "Prekliči",
+    "File already exists" : "Datoteka s tem imenom že obstaja.",
+    "A file with the name {filename} already exists." : "Datoteka z imenom {filename} že obstaja.",
+    "Do you want to overwrite it?" : "Ali želite predmet prepisati?",
+    "Overwrite file" : "Prepiši datoteko",
+    "Keep existing file" : "Ohrani obstoječe datoteke",
+    "This board is read only" : "Zbirka je označena le za branje",
+    "Drop your files to upload" : "Spustite datoteke za pošiljanje v oblak",
     "Archived cards" : "Arhivirane naloge",
-    "Actions" : "Dejanja",
-    "Drop your files here to upload it to the card" : "Spustite datoteke na to mesto za dodajanje k nalogi",
-    "Assign card to me" : "Nalogo dodeli meni",
-    "Unassign card from me" : "Odstrani me z naloge",
-    "Archive card" : "Arhiviraj nalogo",
-    "Unarchive card" : "Povrni nalogo",
-    "Delete card" : "Izbriši nalogo",
-    "Enter a card title" : "Naslov naloge",
-    "Add card" : "Dodaj nalogo",
-    "Close" : "Zapri",
+    "Add new list" : "Dodaj nov seznam",
+    "List name" : "Ime seznama",
+    "Apply filter" : "Uveljavi filter",
+    "Filter by tag" : "Filtriraj po oznaki",
+    "Filter by assigned user" : "Filtriraj po dodeljenem uporabniku",
+    "Filter by due date" : "Filtriraj po datumu preteka",
+    "Overdue" : "Preteklo",
+    "Next 7 days" : "Naslednjih 7 dni",
+    "Next 30 days" : "Naslednjih 30 dni",
+    "No due date" : "Ni datuma preteka",
+    "Show archived cards" : "Prikaži arhivirane naloge",
+    "Toggle compact mode" : "Preklopi način prikaza",
+    "Details" : "Podrobnosti",
+    "Loading board" : "Poteka nalaganje zbirke",
+    "Board not found" : "Zbirke ni mogoče najti",
     "Sharing" : "Souporaba",
     "Tags" : "Oznake",
     "Deleted items" : "Izbrisani predmeti",
     "Timeline" : "Časovnica",
-    "Select users or groups to share with" : "Uporabniki in skupine za souporabo",
-    "Group" : "Skupina",
-    "Circle" : "Krog",
-    "No matching user or group found." : "Ni uporabnikov ali skupin s tem nazivom.",
-    "Loading" : "Poteka nalaganje ...",
-    "Edit" : "Uredi",
-    "Share" : "Souporaba",
-    "Manage" : "Upravljanje",
-    "Discard share" : "Prekliči souporabo",
-    "Sharing has been disabled for your account." : "Za ta račun je možnost dodeljevanja souporabe onemogočena.",
-    "Update tag" : "Posodobi oznako",
-    "Edit tag" : "Uredi oznako",
-    "Delete tag" : "Izbriši oznako",
-    "Create" : "Ustvari",
-    "Create a new tag" : "Ustvari novo oznako",
-    "Deleted stacks" : "Izbrisani paketi nalog",
+    "Undo" : "Razveljavi",
     "Deleted cards" : "Izbrisane naloge",
-    "Status" : "Stanje",
-    "No archived boards to display" : "Ni arhiviranih zbirk za prikaz",
-    "No shared boards to display" : "Ni zbirk v souporabi",
-    "Title" : "Naslov",
-    "Members" : "Člani",
-    "More actions" : "Več možnosti",
+    "Board owner" : "Lastnik zbirke",
+    "(Group)" : "(Skupina)",
+    "(Circle)" : "(Krog)",
+    "Can edit" : "Lahko ureja",
+    "Can share" : "Lahko omogoči souporabo",
+    "Can manage" : "Lahko upravlja",
+    "Delete" : "Izbriši",
+    "Add a new stack" : "Dodaj nov paket nalog",
+    "Delete list" : "Izbriši seznam",
+    "Add card" : "Dodaj nalogo",
+    "Add a new card" : "Dodaj novo nalogo",
+    "Edit" : "Uredi",
+    "title and color value must be provided" : "navedena morata biti podatka naslova in barve",
+    "Delete Attachment" : "Izbriši prilogo",
+    "Restore Attachment" : "Obnovi prilogo",
+    "Assign a tag to this card…" : "Dodeli oznako nalogi ...",
+    "Assign to users" : "Dodeli uporabnikom",
+    "Assign to users/groups/circles" : "Dodeli uporabnikom/skupinam/krogom",
+    "Assign a user to this card…" : "Dodeli uporabnika k nalogi ...",
+    "Due date" : "Datum preteka",
+    "Set a due date" : "Nastavi datum preteka",
+    "Remove due date" : "Odstrani datum preteka",
+    "Description" : "Opis",
+    "(Unsaved)" : "(neshranjeno)",
+    "(Saving…)" : "(shranjevanje ...)",
+    "Formatting help" : "Pomoč pri oblikovanju",
+    "Attachments" : "Priloge",
+    "Comments" : "Opombe",
+    "Modified" : "Spremenjeno",
+    "Created" : "Ustvarjeno",
+    "Upload attachment" : "Pošlji prilogo",
+    "No comments yet. Begin the discussion!" : "Ni še odzivov, bodite prvi!",
+    "Save" : "Shrani",
+    "The comment cannot be empty." : "Polje opombe ne sme biti prazno.",
+    "The comment cannot be longer than 1000 characters." : "Opomba ne sme biti daljša od 1000 znakov.",
+    "In reply to" : "V odgovor",
+    "Reply" : "Odgovori",
+    "Update" : "Posodobi",
+    "(group)" : "(skupina)",
+    "(circle)" : "(krog)",
+    "Assign to me" : "Nalogo dodeli meni",
+    "Delete card" : "Izbriši nalogo",
+    "Move card" : "Premakni nalogo",
+    "Card details" : "Podrobnosti naloge",
+    "Select a stack" : "Izbor paketa nalog",
+    "seconds ago" : "pred nekaj sekundami",
+    "All boards" : "Vse zbirke",
+    "Archived boards" : "Arhivirane zbirke",
+    "Shared boards" : "Zbirke v souporabi",
+    "Settings" : "Nastavitve",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Omejevanje programa prepreči uporabnikom, ki niso del teh skupin, ustvarjanje novih zbirk. Uporabniki bodo še vedno lahko spreminjali zbirke, ki so jih dobili v souporabo.",
+    "New board title" : "Naslov nove zbirke",
+    "Share" : "Souporaba",
+    "Options" : "Možnosti",
     "Edit board" : "Uredi zbirko",
+    "An error occurred" : "Prišlo je do napake.",
+    "Clone board" : "Kloniraj zbirko",
     "Archive board" : "Arhiviraj zbirko",
     "Unarchive board" : "Povrni zbirko",
     "Delete board" : "Izbriši zbirko",
-    "Update board" : "Posodobi zbirko",
-    "Reset board" : "Ponastavi zbirko",
-    "Undo board deletion - Otherwise the board will be deleted during the next cronjob run." : "Razveljavi brisanje zbirke – ta bo sicer izbrisana med naslednjo izvedbo opravila cronjob.",
-    "Create new board" : "Ustvari novo zbirko",
-    "New board title" : "Naslov nove zbirke",
-    "Create board" : "Ustvari zbirko",
-    "Select an attachment" : "Izbor priloge",
-    "Cancel upload" : "Prekliči pošiljanje",
-    "by" : "s strani",
-    "Undo file deletion - Otherwise the file will be deleted during the next cronjob run." : "Razveljavi brisanje datoteke – ta bo sicer izbrisana med naslednjo izvedbo opravila cronjob.",
-    "Undo file deletion" : "Razveljavi brisanje datoteke",
-    "Insert the file into the description" : "Vstavi datoteko v opis",
-    "Delete attachment" : "Izbriši prilogo",
-    "Modified:" : "Spremenjeno:",
-    "Created:" : "Ustvarjeno:",
-    "Choose a tag" : "Izbor oznake",
-    "Add a tag" : "Dodaj oznako",
-    "Select tags" : "Izbor oznak",
-    "Assign users" : "Dodeli uporabnike",
-    "Choose a user to assign" : "Izbor uporabnika za nalogo",
-    "Assign this card to a user" : "Dodeli nalogo uporabniku",
-    "Due date" : "Datum preteka",
-    "Click to set" : "Klik za nastavitev",
-    "Remove due date" : "Odstrani datum preteka",
-    "Description" : "Opis",
-    "Attachments" : "Priloge",
-    "Saved" : "Shranjeno",
-    "Unsaved changes" : "Neshranjene spremembe",
-    "Insert attachment" : "Vstavi prilogo",
-    "Formatting help" : "Pomoč pri oblikovanju",
-    "Upload attachment" : "Pošlji prilogo",
-    "Add a card description…" : "Dodaj opis naloge ...",
-    "Shared boards" : "Zbirke v souporabi",
-    "Move board to archive" : "Premakni zbirko v arhiv",
-    "Create a new board" : "Ustvari novo zbirko",
-    "Settings" : "Nastavitve",
-    "Limit deck to groups" : "Omeji uporabo izbranim skupinam",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Omejevanje programa prepreči uporabnikom, ki niso del teh skupin, ustvarjanje novih zbirk. Uporabniki bodo še vedno lahko spreminjali zbirke, ki so jih dobili v souporabo."
+    "Board details" : "Podrobnosti zbirke",
+    "Link to a board" : "Povezava do zbirke",
+    "Link to a card" : "Povezava do naloge",
+    "Something went wrong" : "Prišlo je do napake ...",
+    "Maximum file size of {size} exceeded" : "Omejitev velikosti datoteke {size} je prekoračena."
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
