@@ -1,15 +1,13 @@
 OC.L10N.register(
     "deck",
     {
-    "Hours" : "Orët",
-    "Minutes" : "Minutat",
-    "File already exists" : "Skedari ekziston tashmë",
     "Deck" : "Shto paisjen U2F",
     "Personal" : "Personale",
     "Finished" : "Përfunduar",
     "To review" : "Për rishikim",
     "Action needed" : "Nevoitet veprim",
     "Later" : "Më vonë",
+    "copy" : "kopjo",
     "To do" : "Për t'u bërë",
     "Doing" : "Duke e bërë",
     "Done" : "Përfunduar",
@@ -17,61 +15,44 @@ OC.L10N.register(
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Kartela e ngarkuar tejkalon udhëzimin MAX_FILE_SIZE që qe përcaktuar te formulari HTML",
     "No file was uploaded" : "S’u ngarkua kartelë",
     "Missing a temporary folder" : "Mungon një dosje e përkohshme",
-    "Add a new stack" : "Shto një raft të ri",
-    "Submit" : "Dërgo",
+    "Create new board" : "Krijo bord të ri",
+    "Cancel" : "Anullo",
+    "File already exists" : "Skedari ekziston tashmë",
+    "Do you want to overwrite it?" : "Doni ta rishkruani atë?",
     "Show archived cards" : "Trego kartat e arkivuara",
-    "Hide archived cards" : "Fsheh kartat e arkivuara ",
-    "All Boards" : "Të gjitha Tabelat ",
-    "Archived boards" : "Borde të arkivuara",
-    "Actions" : "Veprimet",
-    "Enter a card title" : "Fusni një titull karte",
-    "Add card" : "Shto kartë",
-    "Close" : "Mbyll",
-    "Sharing" : "Shpërndaj ",
+    "Details" : "Detajet",
+    "Sharing" : "Ndarje",
     "Tags" : "Etiketa",
-    "Select users or groups to share with" : "Shpërndajeni duke zgjedhur përdorues ose grupe ",
-    "Group" : "Grup",
-    "Circle" : "Rreth",
-    "No matching user or group found." : "Nuk u gjet asnjë përdorues ose grup i përputhshëm.",
-    "Loading" : "Po ngarkohet",
+    "Undo" : "Ktheje pas",
+    "Can edit" : "Can edit",
+    "Can share" : "Mund të ndaj",
+    "Delete" : "Delete",
+    "Add a new stack" : "Shto një raft të ri",
+    "Add card" : "Shto kartë",
     "Edit" : "Edito",
-    "Share" : "Ndaj ",
-    "Manage" : "Menaxho",
-    "Discard share" : "Fshi ndarjen",
-    "Delete tag" : "Fshi etiketën",
-    "Create" : "Krijo",
-    "Create a new tag" : "Krijo një etiketë të re",
-    "Status" : "Status",
-    "Title" : "Titull",
-    "Members" : "Anëtar",
-    "More actions" : "Më tepër veprime ",
+    "Due date" : "Data e vendosur",
+    "Remove due date" : "Hiq datën e mbarimit",
+    "Description" : "Përshkrim",
+    "Formatting help" : "Ndihmë formatimi",
+    "Attachments" : "Bashkangjitjet",
+    "Comments" : "Komentet",
+    "Modified" : "Modifikuar ",
+    "Created" : "U krijua",
+    "Upload attachment" : "Ngarko bashkëngjitje",
+    "Save" : "Ruaj",
+    "Reply" : "Përgjigju",
+    "Update" : "Përditëso",
+    "(group)" : "(grup)",
+    "seconds ago" : "sekonda më parë",
+    "Archived boards" : "Borde të arkivuara",
+    "Shared boards" : "Tabela të shpërndara",
+    "Settings" : "Rregullimet",
+    "New board title" : "Titull i ri bordi",
+    "Share" : "Shpërndaje",
     "Edit board" : "Tabela e editimeve",
     "Archive board" : "Arkivo bordin",
     "Unarchive board" : "Hiq bordin nga arkivi",
     "Delete board" : "Fshij bordin",
-    "Create new board" : "Krijo bord të ri",
-    "New board title" : "Titull i ri bordi",
-    "Cancel upload" : "Anullo ngarkimin",
-    "by" : "nga",
-    "Modified:" : "Modifikuar:",
-    "Created:" : "Krijuar:",
-    "Choose a tag" : "Zgjidh një etiketë",
-    "Add a tag" : "Shto një etiketë",
-    "Select tags" : "Përzgjidh etiketat",
-    "Assign users" : "Cakto përdorues",
-    "Due date" : "Data e vendosur",
-    "Click to set" : "Kliko për të vendosur",
-    "Remove due date" : "Hiq datën e mbarimit",
-    "Description" : "Përshkrim",
-    "Attachments" : "Bashkangjitjet",
-    "Saved" : "I/E ruajtur",
-    "Unsaved changes" : "Ndryshime të paruajtura",
-    "Formatting help" : "Ndihmë formatimi",
-    "Upload attachment" : "Ngarko bashkëngjitje",
-    "Add a card description…" : "Shto një përshkrim të kartës...",
-    "Shared boards" : "Tabela të shpërndara",
-    "Move board to archive" : "Lëviz tabelen në arkivë",
-    "Create a new board" : "Krijo një tablë të re",
-    "Settings" : "Rregullimet"
+    "Board details" : "Detajet e Tabeles "
 },
 "nplurals=2; plural=(n != 1);");
