@@ -2,29 +2,31 @@ OC.L10N.register(
     "deck",
     {
     "Finished" : "Završeno",
+    "copy" : "kopiraj",
     "Done" : "Done",
-    "Share board" : "Podeli tablu",
-    "Assign card to me" : "Dodeli karticu meni",
-    "Unassign card from me" : "Skloni karticu sa mene",
-    "Archive card" : "Arhiviraj karticu",
-    "Delete card" : "Obriši karticu",
-    "Add card" : "Dodaj karticu",
-    "Close" : "Zatvori",
+    "Cancel" : "Otkaži",
+    "Details" : "Detalji",
     "Sharing" : "Deljenje",
     "Tags" : "Oznake",
-    "Group" : "Group",
-    "Loading" : "Loading",
+    "Undo" : "Opozovi",
+    "Can edit" : "Can edit",
+    "Can share" : "Can share",
+    "Delete" : "Obriši",
+    "Add card" : "Dodaj karticu",
     "Edit" : "Uredi",
-    "Share" : "Deljenje",
-    "Create" : "Napravi",
-    "Title" : "Naslov",
-    "Edit board" : "Izmeni tablu",
-    "Archive board" : "Arhiviraj tablu",
-    "Delete board" : "Izbriši tablu",
-    "Assign users" : "Dodelite korisnike",
     "Due date" : "Rok",
     "Description" : "Opis",
     "Attachments" : "Prilozi",
-    "Settings" : "Postavke"
+    "Save" : "Sačuvaj",
+    "Reply" : "Odgovori",
+    "Update" : "Ažuriraj",
+    "Delete card" : "Obriši karticu",
+    "Move card" : "Premesti karticu",
+    "seconds ago" : "pre nekoliko sekundi",
+    "Settings" : "Postavke",
+    "Share" : "Podeli",
+    "Edit board" : "Izmeni tablu",
+    "Archive board" : "Arhiviraj tablu",
+    "Delete board" : "Izbriši tablu"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
