@@ -1,17 +1,6 @@
 OC.L10N.register(
     "deck",
     {
-    "Please provide a content for your comment." : "Ange ett innehåll för din kommentar.",
-    "Posting the comment failed." : "Det gick inte att skriva in kommentaren.",
-    "The comment has been deleted" : "Kommentaren har tagits bort",
-    "The associated stack is deleted as well, it will be restored as well." : "Den tillhörande stapeln raderas också, den kommer också att återställas.",
-    "Restore associated stack" : "Återställ tillhörande stapel",
-    "Remove user from card" : "Ta bort användare från kort",
-    "Hours" : "Timmar",
-    "Minutes" : "Minuter",
-    "Link to a board" : "Länka till en tavla",
-    "Maximum file size of {size} exceeded" : "Maximal filstorlek på {size} överskriden",
-    "File already exists" : "Filen finns redan",
     "You have created a new board {board}" : "Du har skapat en ny tavla {board}",
     "{user} has created a new board {board}" : "{user} har skapat en ny tavla {board}",
     "You have deleted the board {board}" : "Du har raderat tavlan {board}",
@@ -91,6 +80,7 @@ OC.L10N.register(
     "To review" : "Att granska",
     "Action needed" : "Åtgärd behövs",
     "Later" : "Senare",
+    "copy" : "kopiera",
     "To do" : "Att göra",
     "Doing" : "Gör",
     "Done" : "Klart",
@@ -106,98 +96,111 @@ OC.L10N.register(
     "Could not write file to disk" : "Kunde inte skriva fil till disk",
     "A PHP extension stopped the file upload" : "Ett PHP-tillägg stoppade filuppladdningen",
     "No file uploaded or file size exceeds maximum of %s" : "Ingen fil uppladdad eller filstorleken överstiger max %s",
-    "A kanban style project and personal management tool for Nextcloud" : "En kanban-liknande projekt- och person-hanteringsapp för Nextcloud ",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Korthögar är en kanban-liknande projekt- och organiseringsapp för arbetsgrupper i Nextcloud.\n\n\n- 📥 Lägg till uppgifter på kort och ordna dem\n- 📄 Skriv anteckningar i markdown\n- 🔖 Tilldela etiketter för organisering\n- 👥 Dela med arbetsgruppen, vänner eller familj\n- 📎 Bifoga filer och bädda in dem i markdown-anteckningarna\n- 💬 Diskutera i arbetsgruppen genom kommentarer\n- ⚡ Håll koll på ändringar i aktivitetsflödet\n- 🚀 Börja organisera din arbetsgrupp nu!",
+    "Create new board" : "Skapa ny tavla",
+    "new board" : "ny tavla",
     "Select the board to link to a project" : "Välj tavla att länka till ett projekt",
     "Select board" : "Välj tavla",
-    "Add a new stack" : "Lägg till en ny stapel",
-    "Submit" : "Skapa",
-    "Show archived cards" : "Visa arkiverade kort",
-    "Hide archived cards" : "Göm arkiverade kort",
-    "Toggle compact mode" : "Växla kompakt läge",
-    "Show board details" : "Visa taveldetaljer",
-    "All Boards" : "Alla tavlor",
-    "Archived boards" : "Arkiverade tavlor",
-    "Share board" : "Dela tavla",
+    "Select the card to link to a project" : "Välj kort att länka till ett projekt",
+    "Select a board" : "Välj en tavla",
+    "Select a card" : "Välj ett kort",
+    "Link to card" : "Länka till kort",
+    "Cancel" : "Avbryt",
+    "File already exists" : "Filen finns redan",
+    "A file with the name {filename} already exists." : "En fil med namnet {filename} finns redan.",
+    "Do you want to overwrite it?" : "Vill du skriva över det?",
+    "Overwrite file" : "Skriv över filen",
+    "Keep existing file" : "Behåll nuvarande fil",
+    "This board is read only" : "Denna tavla är skrivskyddad",
+    "Drop your files to upload" : "Släpp dina filer för att ladda upp",
     "Archived cards" : "Arkiverade kort",
-    "Actions" : "Åtgärder",
-    "Drop your files here to upload it to the card" : "Släpp dina filer här för att ladda upp det till kortet",
-    "Assign card to me" : "Tilldela kort till mig",
-    "Unassign card from me" : "Ta bort kort från mig",
-    "Archive card" : "Arkivera kort",
-    "Unarchive card" : "Avarkivera kort",
-    "Delete card" : "Ta bort kort",
-    "Enter a card title" : "Ange en korttitel",
-    "Add card" : "Lägg till kort",
-    "Close" : "Stäng",
+    "Add new list" : "Lägg till en ny lista",
+    "List name" : "Namn på lista",
+    "Apply filter" : "Tillämpa filter",
+    "Filter by tag" : "Filtrera efter tagg",
+    "Filter by assigned user" : "Filtrera efter tilldelad användare",
+    "Filter by due date" : "Filtrera efter förfallodatum",
+    "Overdue" : "Förfallen",
+    "Next 7 days" : "Nästa 7 dagar",
+    "Next 30 days" : "Nästa 30 dagar",
+    "No due date" : "Inget slutdatum",
+    "Show archived cards" : "Visa arkiverade kort",
+    "Toggle compact mode" : "Växla kompakt läge",
+    "Details" : "Detaljer",
+    "Loading board" : "Läser in tavla",
+    "Board not found" : "Tavlan hittades inte",
     "Sharing" : "Delning",
     "Tags" : "Taggar",
     "Deleted items" : "Raderade objekt",
     "Timeline" : "Tidslinje",
-    "Select users or groups to share with" : "Välj användare och grupper att dela med",
-    "Group" : "Grupp",
-    "Circle" : "Cirkel",
-    "No matching user or group found." : "Ingen matchande användare eller grupp hittades.",
-    "Loading" : "Laddar",
-    "Edit" : "Redigera",
-    "Share" : "Dela",
-    "Manage" : "Hantera",
-    "Discard share" : "Ta bort delning",
-    "Sharing has been disabled for your account." : "Delning har inaktiverats för ditt konto.",
-    "Update tag" : "Uppdatera tagg",
-    "Edit tag" : "Redigera tagg",
-    "Delete tag" : "Radera tagg",
-    "Create" : "Skapa",
-    "Create a new tag" : "Skapa en ny tagg",
-    "Deleted stacks" : "Radera staplar",
+    "Deleted lists" : "Raderade listor",
+    "Undo" : "Ångra",
     "Deleted cards" : "Radera kort",
-    "Status" : "Status",
-    "No archived boards to display" : "Inga arkiverade tavlor att visa",
-    "No shared boards to display" : "Inga delade tavlor att visa",
-    "Title" : "Titel",
-    "Members" : "Medlemmar",
-    "More actions" : "Fler händelser",
+    "Share board with a user, group or circle …" : "Dela en tavla med en användare, grupp eller cirkel ...",
+    "Board owner" : "Tavlans ägare",
+    "(Group)" : "(Grupp)",
+    "(Circle)" : "(Cirkel)",
+    "Can edit" : "Kan redigera",
+    "Can share" : "Kan dela",
+    "Can manage" : "Kan hanter",
+    "Delete" : "Radera",
+    "Add a new stack" : "Lägg till en ny stapel",
+    "Delete list" : "Radera lista",
+    "Add card" : "Lägg till kort",
+    "Add a new card" : "Lägg till ett nytt kort",
+    "Edit" : "Redigera",
+    "Add a new tag" : "Lägg till en ny tagg",
+    "title and color value must be provided" : "titel och färg måste anges",
+    "Delete Attachment" : "Ta bort bilaga",
+    "Restore Attachment" : "Återställ bilaga",
+    "Assign a tag to this card…" : "Tilldela en tagg till det här kortet ...",
+    "Assign to users" : "Tilldela till användare",
+    "Assign to users/groups/circles" : "Tilldela till användare/grupper/cirklar",
+    "Assign a user to this card…" : "Tilldela en användare till det här kortet ...",
+    "Due date" : "Slutdatum",
+    "Set a due date" : "Sätt ett slutdatum",
+    "Remove due date" : "Ta bort slutdatum",
+    "Description" : "Beskrivning",
+    "(Unsaved)" : "(Inte sparad)",
+    "(Saving…)" : "(Sparar…)",
+    "Formatting help" : "Formatteringshjälp",
+    "Attachments" : "Bilagor",
+    "Comments" : "Kommentarer",
+    "Modified" : "Ändrad",
+    "Created" : "Skapat",
+    "Upload attachment" : "Ladda upp bilaga",
+    "No comments yet. Begin the discussion!" : "Inga kommentarer än. Börja diskussionen!",
+    "Save" : "Spara",
+    "The comment cannot be empty." : "Kommentaren kan inte vara tom.",
+    "The comment cannot be longer than 1000 characters." : "Kommentaren kan inte vara längre än 1000 tecken.",
+    "In reply to" : "Som svar på",
+    "Reply" : "Svara",
+    "Update" : "Uppdatera",
+    "(group)" : " (grupp)",
+    "(circle)" : "(cirkel)",
+    "Assign to me" : "Tilldela till mig",
+    "Delete card" : "Ta bort kort",
+    "Move card" : "Flytta kort",
+    "Card details" : "Kortdetaljer",
+    "Select a stack" : "Välj en stapel",
+    "seconds ago" : "sekunder sedan",
+    "All boards" : "Alla tavlor",
+    "Archived boards" : "Arkiverade tavlor",
+    "Shared boards" : "Delade tavlor",
+    "Settings" : "Inställningar",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Begränsa Deck blockerar användare som inte ingår i dessa grupper från att skapa egna tavlor. Användare kan fortfarande arbeta med tavlor som har delats med dem.",
+    "New board title" : "Ny titel för tavla",
+    "Share" : "Dela",
     "Edit board" : "Ändra tavla",
+    "An error occurred" : "Ett fel uppstod",
+    "Clone board" : "Kopiera tavla",
     "Archive board" : "Arkivera tavla",
     "Unarchive board" : "Ta bort tavlan ur arkivet",
     "Delete board" : "Ta bort tavla",
-    "Update board" : "Uppdatera tavla",
-    "Reset board" : "Återställ tavla",
-    "Undo board deletion - Otherwise the board will be deleted during the next cronjob run." : "Ångra tavelradering - annars kommer tavlan att raderas när nästa cronjob körs.",
-    "Create new board" : "Skapa ny tavla",
-    "New board title" : "Ny taveltitel",
-    "Create board" : "Skapa tavla",
-    "Select an attachment" : "Välj en bilaga",
-    "Cancel upload" : "Avbryt uppladdning",
-    "by" : "av",
-    "Undo file deletion - Otherwise the file will be deleted during the next cronjob run." : "Ångra filborttagning - annars kommer filen att tas bort när nästa cronjob körs.",
-    "Undo file deletion" : "Ångra filborttagning",
-    "Insert the file into the description" : "Infoga filen i beskrivningen",
-    "Delete attachment" : "Ta bort bilaga",
-    "Modified:" : "Ändrad:",
-    "Created:" : "Skapad:",
-    "Choose a tag" : "Välj en tagg",
-    "Add a tag" : "Lägg till en tagg",
-    "Select tags" : "Välj taggar",
-    "Assign users" : "Tilldela användare",
-    "Choose a user to assign" : "Välj en användare att tilldela",
-    "Assign this card to a user" : "Tilldela detta kort till en användare",
-    "Due date" : "Slutdatum",
-    "Click to set" : "Ange datum",
-    "Remove due date" : "Ta bort slutdatum",
-    "Description" : "Beskrivning",
-    "Attachments" : "Bilagor",
-    "Saved" : "Sparad",
-    "Unsaved changes" : "Osparade ändringar",
-    "Insert attachment" : "Infoga bilaga",
-    "Formatting help" : "Formatteringshjälp",
-    "Upload attachment" : "Ladda upp bilaga",
-    "Add a card description…" : "Lägg till en kortbeskrivning...",
-    "Shared boards" : "Delade tavlor",
-    "Move board to archive" : "Flytta tavlan till arkivet",
-    "Create a new board" : "Skapa en ny tavla",
-    "Settings" : "Inställningar",
-    "Limit deck to groups" : "Begränsa Deck till grupper",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Begränsa Deck blockerar användare som inte ingår i dessa grupper från att skapa egna tavlor. Användare kan fortfarande arbeta med tavlor som har delats med dem."
+    "Board details" : "Taveldetaljer",
+    "Link to a board" : "Länka till en tavla",
+    "Link to a card" : "Länka till ett kort",
+    "Something went wrong" : "Något gick fel",
+    "Maximum file size of {size} exceeded" : "Maximal filstorlek på {size} överskriden"
 },
 "nplurals=2; plural=(n != 1);");
