@@ -6,20 +6,19 @@ OC.L10N.register(
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "பதிவேற்றப்பட்ட கோப்பானது HTML  படிவத்தில் குறிப்பிடப்பட்டுள்ள MAX_FILE_SIZE  directive ஐ விட கூடியது",
     "No file was uploaded" : "எந்த கோப்பும் பதிவேற்றப்படவில்லை",
     "Missing a temporary folder" : "ஒரு தற்காலிகமான கோப்புறையை காணவில்லை",
-    "Actions" : "செயல்கள்",
-    "Close" : "மூடுக",
+    "Cancel" : "இரத்து செய்க",
+    "Details" : "விவரங்கள்",
     "Tags" : "சீட்டுகள்",
-    "Group" : "Group",
-    "Loading" : "Loading",
+    "Can edit" : "Can edit",
+    "Can share" : "Can share",
+    "Delete" : "நீக்குக",
     "Edit" : "தொகுக்க",
-    "Share" : "பகிர்வு",
-    "Create" : "உருவாக்குக",
-    "Title" : "தலைப்பு",
-    "Cancel upload" : "பதிவேற்றலை இரத்து செய்க",
-    "by" : "மூலம்",
-    "Modified:" : "மாற்றப்பட்டது:",
-    "Created:" : "உருவாக்கப்பட்டது:",
     "Description" : "விவரிப்பு",
-    "Settings" : "அமைப்புகள்"
+    "Modified" : "மாற்றப்பட்டது",
+    "Save" : "சேமிக்க ",
+    "Update" : "இற்றைப்படுத்தல்",
+    "seconds ago" : "செக்கன்களுக்கு முன்",
+    "Settings" : "அமைப்புகள்",
+    "Share" : "பகிர்வு"
 },
 "nplurals=2; plural=(n != 1);");
