@@ -1,71 +1,61 @@
 OC.L10N.register(
     "deck",
     {
-    "Hours" : "Годин",
-    "Minutes" : "Хвилин",
-    "File already exists" : "Файл вже існує",
+    "You have created a new board {board}" : "Ви створили новц дошку {board}",
+    "{user} has created a new board {board}" : "{user} створив нову дошку {board}",
+    "You have deleted the board {board}" : "Ви вилучили дошку {board}",
+    "{user} has deleted the board {board}" : "{user} вилучив дошку {board}",
+    "You have restored the board {board}" : "Ви відновили дошку {board}",
     "Deck" : "Колода",
     "Personal" : "Особисте",
     "Finished" : "Завершено",
     "To review" : "На перегляд",
     "Action needed" : "Потребує дій",
     "Later" : "Пізніше",
+    "copy" : "копіювати",
     "Done" : "Готово",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Розмір вивантаженого файлу перевищує директиву MAX_FILE_SIZE вказану в HTML формі",
     "No file was uploaded" : "Не вивантажено жодного файлу",
     "Missing a temporary folder" : "Відсутній тимчасовий каталог",
-    "Add a new stack" : "Додати нову купу",
+    "Create new board" : "Створити нову дошку",
+    "Cancel" : "Скасувати",
+    "File already exists" : "Файл вже існує",
     "Show archived cards" : "Показати архівні картки",
-    "Hide archived cards" : "Приховати архівні картки",
-    "All Boards" : "Всі дошки",
-    "Archived boards" : "Архівовані дошки",
-    "Share board" : "Поширити дошку",
-    "Actions" : "Дії",
-    "Assign card to me" : "Прив'язати картку до мене",
-    "Unassign card from me" : "Відв'язати картку від мене",
-    "Archive card" : "Архівувати картку",
-    "Delete card" : "Видалити картку",
-    "Enter a card title" : "Введіть заголовок картки",
-    "Add card" : "Додати картку",
-    "Close" : "Закрити",
+    "Details" : "Деталі",
     "Sharing" : "Поділитись",
     "Tags" : "Теги",
-    "Select users or groups to share with" : "Оберіть користувача або групу щоб поділитись",
-    "Group" : "Група",
-    "Circle" : "Коло",
-    "No matching user or group found." : "Користувачів або груп не знайдено",
-    "Loading" : "Завантаження",
+    "Undo" : "відмінити",
+    "Can edit" : "Можна редагувати",
+    "Can share" : "Can share",
+    "Delete" : "Видалити",
+    "Add a new stack" : "Додати нову купу",
+    "Delete list" : "Вилучити список",
+    "Add card" : "Додати картку",
     "Edit" : "Редагувати",
-    "Share" : "Поділитись",
-    "Manage" : "Керувати",
-    "Discard share" : "Відмінити спільне використання",
-    "Create" : "Створити",
-    "Create a new tag" : "Створити новий тег",
-    "Title" : "Заголовок",
-    "Members" : "Учасники",
-    "More actions" : "Більше дій",
+    "Due date" : "Протягом",
+    "Remove due date" : "Видалити до",
+    "Description" : "Опис",
+    "Formatting help" : "Форматування довідки",
+    "Attachments" : "Вкладення",
+    "Comments" : "Коментарі",
+    "Modified" : "Змінено",
+    "Save" : "Зберегти",
+    "Reply" : "Відповісти",
+    "Update" : "Оновлення",
+    "(group)" : "(група)",
+    "Delete card" : "Видалити картку",
+    "Move card" : "Пересунути картку",
+    "seconds ago" : "секунд тому",
+    "Archived boards" : "Архівовані дошки",
+    "Shared boards" : "Спільні дошки",
+    "Settings" : "Налаштування",
+    "New board title" : "Новий заголовок дошки",
+    "Share" : "Поділитися",
     "Edit board" : "Змінити дошку",
+    "An error occurred" : "Виникла помилка",
     "Archive board" : "Архівувати дошку",
     "Unarchive board" : "Розархівувати дошку",
     "Delete board" : "Видалити дошку",
-    "Create new board" : "Створити нову дошку",
-    "New board title" : "Новий заголовок дошки",
-    "Cancel upload" : "Скасувати завантаження",
-    "by" : "від",
-    "Modified:" : "Змінено:",
-    "Created:" : "Створено:",
-    "Assign users" : "Додавання користувача",
-    "Due date" : "Протягом",
-    "Click to set" : "Клацніть для налаштування",
-    "Remove due date" : "Видалити до",
-    "Description" : "Опис",
-    "Attachments" : "Вкладення",
-    "Saved" : "Збережено",
-    "Formatting help" : "Форматування довідки",
-    "Add a card description…" : "Додати опис дошки",
-    "Shared boards" : "Спільні дошки",
-    "Move board to archive" : "Перемістити до архіву",
-    "Create a new board" : "Створити нову дошку",
-    "Settings" : "Налаштування"
+    "Board details" : "Деталі дошки"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
