@@ -1,12 +1,6 @@
 OC.L10N.register(
     "deck",
     {
-    "The associated stack is deleted as well, it will be restored as well." : "Giai đoạn liên quan đã bị xóa, nó cũng có thể được khôi phục lại.",
-    "Restore associated stack" : "Khôi phục giai đoạn được liên kết",
-    "Remove user from card" : "Loại bỏ người dùng khỏi tác vụ",
-    "Hours" : "Giờ",
-    "Minutes" : "Phút",
-    "Maximum file size of {size} exceeded" : "Đã vượt quá kích thước {size} tối đa tập tin",
     "You have created a new board {board}" : "Bạn đã tạo một dự án mới {board}",
     "{user} has created a new board {board}" : "{user} đã tạo một dự án mới {board}",
     "You have deleted the board {board}" : "Bạn đã xóa một dự án {board}",
@@ -50,74 +44,46 @@ OC.L10N.register(
     "Could not write file to disk" : "Không thể ghi tệp lên hệ thống",
     "A PHP extension stopped the file upload" : "Một chức năng mở rộng của PHP đã dừng tải tệp lên",
     "No file uploaded or file size exceeds maximum of %s" : "Chưa có tệp nào được tải lên hoặc kích thước tệp vượt quá giới hạn của %s",
-    "A kanban style project and personal management tool for Nextcloud" : "Dự án theo kiểu kanban và công cụ quản lý cá nhân cho Hệ thống",
-    "Add a new stack" : "Thêm một giai đoạn mới",
-    "Submit" : "Gửi đi",
+    "Create new board" : "Tạo dự án mới",
+    "Cancel" : "Hủy bỏ",
     "Show archived cards" : "Hiện tác vụ đã lưu trữ",
-    "Hide archived cards" : "Ẩn tác vụ đã lưu trữ",
     "Toggle compact mode" : "Chuyển đổi chế độ thu gọn",
-    "All Boards" : "Tất cả dự án",
-    "Archived boards" : "Dự án đã lưu trữ",
-    "Share board" : "Dự án chia sẽ",
-    "Actions" : "Hành động",
-    "Drop your files here to upload it to the card" : "Thả tệp của bạn vào đây để tải nó lên tác vụ",
-    "Enter a card title" : "Nhập tên tác vụ",
-    "Add card" : "Thêm tác vụ",
-    "Close" : "Đóng",
+    "Details" : "Thông tin",
     "Sharing" : "Đang chia sẽ",
     "Tags" : "Thẻ",
-    "Select users or groups to share with" : "Chọn người dùng hoặc nhóm để chia sẽ với",
-    "Group" : "N",
-    "Circle" : "Vòng kết nối",
-    "No matching user or group found." : "Không tìm thấy người dùng hoặc nhóm.",
-    "Loading" : "Đang tải",
+    "Can edit" : "Có thể chỉnh sửa",
+    "Can share" : "Can share",
+    "Delete" : "Xóa",
+    "Add a new stack" : "Thêm một giai đoạn mới",
+    "Add card" : "Thêm tác vụ",
+    "Add a new card" : "Thêm một tác vụ mới",
     "Edit" : "Chỉnh sửa",
-    "Share" : "Chia sẽ",
-    "Manage" : "Quản lý",
-    "Discard share" : "Hủy chia sẽ",
-    "Create" : "Tạo",
-    "Create a new tag" : "Tạo một thẻ mới",
-    "Status" : "Trạng thái",
-    "No archived boards to display" : "Không có dự án đã lưu trữ nào để hiển thị",
-    "No shared boards to display" : "Không có dự án đã được chia sẽ nào để hiển thị",
-    "Title" : "Tên",
-    "Members" : "Thành viên",
-    "More actions" : "Nhiều hành động hơn",
+    "Due date" : "Thời hạn",
+    "Remove due date" : "Xóa thời hạn",
+    "Description" : "Mô tả",
+    "Formatting help" : "Định dạng trợ giúp",
+    "Attachments" : "Đính kèm",
+    "Comments" : "Các bình luận",
+    "Modified" : "Thay đổi",
+    "Created" : "Đã tạo",
+    "Upload attachment" : "Tải lên một đính kèm",
+    "Save" : "Lưu",
+    "Reply" : "Trả l",
+    "Update" : "Cập nhật",
+    "(group)" : "(nhóm)",
+    "Assign to me" : "Phân công cho tôi",
+    "seconds ago" : "vài giây trước",
+    "Archived boards" : "Dự án đã lưu trữ",
+    "Shared boards" : "Chia sẽ dự án",
+    "Settings" : "Thiết lập",
+    "New board title" : "Tên dự án mới",
+    "Share" : "Chia sẻ",
     "Edit board" : "Chỉnh sửa dự án",
+    "An error occurred" : "Có lỗi đã xảy ra",
     "Archive board" : "Lưu trữ dự án",
     "Unarchive board" : "Bỏ lưu trữ dự án",
     "Delete board" : "Xóa dự án",
-    "Undo board deletion - Otherwise the board will be deleted during the next cronjob run." : "Hoàn tác dự án đã xóa - Nếu không, Dự án sẽ bị xóa trong lần quét Hệ thống tiếp theo.",
-    "Create new board" : "Tạo dự án mới",
-    "New board title" : "Tên dự án mới",
-    "Select an attachment" : "Chọn một đính kèm",
-    "Cancel upload" : "Hủy tải lên",
-    "by" : "bởi",
-    "Undo file deletion - Otherwise the file will be deleted during the next cronjob run." : "Hoàn tác file đã xóa - Nếu không, file sẽ bị xóa trong lần quét hệ thống tiếp theo.",
-    "Undo file deletion" : "Hoàn tác file đã xóa",
-    "Insert the file into the description" : "Chèn tệp vào mô tả",
-    "Modified:" : "Đã sửa:",
-    "Created:" : "Đã tạo:",
-    "Choose a tag" : "Chọn một thẻ",
-    "Add a tag" : "Thêm một thẻ",
-    "Select tags" : "Chọn một thẻ",
-    "Assign users" : "Chỉ định người dùng",
-    "Choose a user to assign" : "Chọn một người dùng để phân công",
-    "Assign this card to a user" : "Phân công tác vụ cho người dùng",
-    "Due date" : "Thời hạn",
-    "Click to set" : "Bấm để thiết đặt",
-    "Remove due date" : "Xóa thời hạn",
-    "Description" : "Mô tả",
-    "Attachments" : "Đính kèm",
-    "Saved" : "Đã lưu",
-    "Unsaved changes" : "Thay đổi chưa được lưu",
-    "Insert attachment" : "Thêm đính kèm",
-    "Formatting help" : "Định dạng trợ giúp",
-    "Upload attachment" : "Tải lên một đính kèm",
-    "Add a card description…" : "Thêm một mô tả tác vụ...",
-    "Shared boards" : "Chia sẽ dự án",
-    "Move board to archive" : "Di chuyển dự án sang lưu trữ",
-    "Create a new board" : "Tạo dự án mới",
-    "Settings" : "Thiết lập"
+    "Board details" : "Thông tin dự án",
+    "Maximum file size of {size} exceeded" : "Đã vượt quá kích thước {size} tối đa tập tin"
 },
 "nplurals=1; plural=0;");
