@@ -1,16 +1,6 @@
 OC.L10N.register(
     "deck",
     {
-    "Posting the comment failed." : "儲存註解失敗",
-    "The comment has been deleted" : "註解已刪除",
-    "The associated stack is deleted as well, it will be restored as well." : "相關的項目已被刪除，他將被還原",
-    "Restore associated stack" : "還原相關項目",
-    "Remove user from card" : "將使用者從項目卡中移除",
-    "Hours" : "小時",
-    "Minutes" : "分鐘",
-    "Link to a board" : "連結到佈告欄",
-    "Maximum file size of {size} exceeded" : "達到最大的檔案大小 {size} ",
-    "File already exists" : "檔案已存在",
     "You have created a new board {board}" : "您已建立新的佈告欄 {board}",
     "{user} has created a new board {board}" : "{user} 已建立新的佈告欄  {board}",
     "You have deleted the board {board}" : "您已刪除佈告欄 {board}",
@@ -22,6 +12,7 @@ OC.L10N.register(
     "Personal" : "私人的",
     "Finished" : "已完成",
     "Later" : "稍後",
+    "copy" : "複製",
     "Done" : "完成",
     "The file was uploaded" : "檔案已上傳",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
@@ -29,43 +20,46 @@ OC.L10N.register(
     "Missing a temporary folder" : "找不到暫存資料夾",
     "Could not write file to disk" : "寫入硬碟失敗",
     "A PHP extension stopped the file upload" : "一個 PHP 擴充功能終止檔案的上傳",
-    "Submit" : "送出",
-    "Actions" : "動作",
-    "Archive card" : "封存作業",
-    "Delete card" : "刪除作業",
-    "Close" : "關閉",
+    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck是一種看板式組織工具，旨在針對與Nextcloud集成的團隊進行個人計劃和項目組織。\n\n\n- 📥 增加您的任務到card和把它們整理好\n- 📄 寫下額外的筆記在markdown\n- 🔖 分配標籤以更好地組織\n- 👥 與您的團隊，朋友或家人分享\n- 📎 附加檔案並將其嵌入到您的 markdown 描述\n- 💬 使用評論與您的團隊討論\n- ⚡ 跟踪變化在活動流程中\n- 🚀 取得您的專案組織",
+    "Cancel" : "取消",
+    "File already exists" : "檔案已存在",
+    "Add new list" : "新增清單",
+    "Details" : "詳細資料",
     "Sharing" : "分享",
     "Tags" : "標籤",
-    "Select users or groups to share with" : "分享給指定的使用者或群組",
-    "Group" : "群組",
-    "Circle" : "圈子",
-    "No matching user or group found." : "沒有群組或使用者符合。",
-    "Loading" : "載入中",
+    "Deleted items" : "刪除的項目",
+    "Timeline" : "時間軸",
+    "Undo" : "復原",
+    "Can edit" : "可以編輯",
+    "Can share" : "可以分享",
+    "Delete" : "刪除",
+    "Delete list" : "刪除清單",
+    "Add card" : "增加卡片",
     "Edit" : "編輯",
-    "Share" : "分享",
-    "Manage" : "管理",
-    "Create" : "建立",
-    "Create a new tag" : "建立新標籤",
-    "Status" : "狀態",
-    "Title" : "標題",
-    "Members" : "成員",
-    "More actions" : "更多",
-    "Edit board" : "編輯專案",
-    "Archive board" : "封存的專案",
-    "Delete board" : "刪除的專案",
-    "Create board" : "建立專案",
-    "Cancel upload" : "取消上傳",
-    "by" : "由",
-    "Modified:" : "修改：",
-    "Created:" : "建立：",
-    "Select tags" : "選擇標籤",
-    "Assign users" : "指派負責人",
+    "Assign to users" : "分派給使用者",
     "Due date" : "截止日",
-    "Click to set" : "點此來設定",
     "Description" : "描述",
     "Attachments" : "附件",
-    "Saved" : "已儲存",
+    "Comments" : "意見",
+    "Modified" : "已修改",
+    "Created" : "已新增",
     "Upload attachment" : "上傳附件",
-    "Settings" : "設定"
+    "Save" : "儲存",
+    "Reply" : "回覆",
+    "Update" : "更新",
+    "(group)" : "(群組)",
+    "Assign to me" : "分派給我",
+    "Delete card" : "刪除作業",
+    "Move card" : "移動卡片",
+    "seconds ago" : "幾秒前",
+    "Settings" : "設定",
+    "Share" : "分享",
+    "Options" : "設定",
+    "Edit board" : "編輯專案",
+    "An error occurred" : "發生錯誤",
+    "Archive board" : "封存的專案",
+    "Delete board" : "刪除的專案",
+    "Link to a board" : "連結到佈告欄",
+    "Maximum file size of {size} exceeded" : "達到最大的檔案大小 {size} "
 },
 "nplurals=1; plural=0;");
