@@ -25,7 +25,6 @@
 
 namespace OCA\Deck\Activity;
 
-
 use cogpowered\FineDiff\Diff;
 use OCA\Deck\Db\Acl;
 use OCP\Activity\IEvent;
@@ -179,27 +178,30 @@ class DeckProvider implements IProvider {
 	}
 
 	private function getIcon(IEvent $event) {
-		$event->setIcon($this->urlGenerator->imagePath('deck', 'deck-dark.svg'));
+		$event->setIcon($this->urlGenerator->getAbsoluteURL($this->urlGenerator->imagePath('deck', 'deck-dark.svg')));
 		if (strpos($event->getSubject(), '_update') !== false) {
-			$event->setIcon($this->urlGenerator->imagePath('files', 'change.svg'));
+			$event->setIcon($this->urlGenerator->getAbsoluteURL($this->urlGenerator->imagePath('files', 'change.svg')));
 		}
 		if (strpos($event->getSubject(), '_create') !== false) {
-			$event->setIcon($this->urlGenerator->imagePath('files', 'add-color.svg'));
+			$event->setIcon($this->urlGenerator->getAbsoluteURL($this->urlGenerator->imagePath('files', 'add-color.svg')));
 		}
 		if (strpos($event->getSubject(), '_delete') !== false) {
-			$event->setIcon($this->urlGenerator->imagePath('files', 'delete-color.svg'));
+			$event->setIcon($this->urlGenerator->getAbsoluteURL($this->urlGenerator->imagePath('files', 'delete-color.svg')));
 		}
 		if (strpos($event->getSubject(), 'archive') !== false) {
-			$event->setIcon($this->urlGenerator->imagePath('deck', 'archive.svg'));
+			$event->setIcon($this->urlGenerator->getAbsoluteURL($this->urlGenerator->imagePath('deck', 'archive.svg')));
 		}
 		if (strpos($event->getSubject(), '_restore') !== false) {
-			$event->setIcon($this->urlGenerator->imagePath('core', 'actions/history.svg'));
+			$event->setIcon($this->urlGenerator->getAbsoluteURL($this->urlGenerator->imagePath('core', 'actions/history.svg')));
 		}
 		if (strpos($event->getSubject(), 'attachment_') !== false) {
-			$event->setIcon($this->urlGenerator->imagePath('core', 'places/files.svg'));
+			$event->setIcon($this->urlGenerator->getAbsoluteURL($this->urlGenerator->imagePath('core', 'places/files.svg')));
 		}
 		if (strpos($event->getSubject(), 'comment_') !== false) {
-			$event->setIcon($this->urlGenerator->imagePath('core', 'actions/comment.svg'));
+			$event->setIcon($this->urlGenerator->getAbsoluteURL($this->urlGenerator->imagePath('core', 'actions/comment.svg')));
+		}
+		if (strpos($event->getSubject(), 'label_') !== false) {
+			$event->setIcon($this->urlGenerator->getAbsoluteURL($this->urlGenerator->imagePath('core', 'actions/tag.svg')));
 		}
 		return $event;
 	}
