@@ -26,13 +26,13 @@ namespace OCA\Deck\Service;
 
 use OCA\Deck\Activity\ActivityManager;
 use OCA\Deck\Activity\ChangeSet;
-use OCA\Deck\Collaboration\Resources\ResourceProvider;
 use OCA\Deck\Db\Acl;
 use OCA\Deck\Db\AclMapper;
 use OCA\Deck\Db\AssignedUsersMapper;
 use OCA\Deck\Db\ChangeHelper;
 use OCA\Deck\Db\IPermissionMapper;
 use OCA\Deck\Db\Label;
+use OCA\Deck\Db\Stack;
 use OCA\Deck\Db\StackMapper;
 use OCA\Deck\NoPermissionException;
 use OCA\Deck\Notification\NotificationHelper;
@@ -47,9 +47,7 @@ use OCA\Deck\BadRequestException;
 use Symfony\Component\EventDispatcher\EventDispatcherInterface;
 use Symfony\Component\EventDispatcher\GenericEvent;
 
-
 class BoardService {
-
 	private $boardMapper;
 	private $stackMapper;
 	private $labelMapper;
@@ -133,10 +131,10 @@ class BoardService {
 				}
 				$permissions = $this->permissionService->matchPermissions($item);
 				$item->setPermissions([
-					'PERMISSION_READ' => $permissions[Acl::PERMISSION_READ],
-					'PERMISSION_EDIT' => $permissions[Acl::PERMISSION_EDIT],
-					'PERMISSION_MANAGE' => $permissions[Acl::PERMISSION_MANAGE],
-					'PERMISSION_SHARE' => $permissions[Acl::PERMISSION_SHARE]
+					'PERMISSION_READ' => $permissions[Acl::PERMISSION_READ] ?? false,
+					'PERMISSION_EDIT' => $permissions[Acl::PERMISSION_EDIT] ?? false,
+					'PERMISSION_MANAGE' => $permissions[Acl::PERMISSION_MANAGE] ?? false,
+					'PERMISSION_SHARE' => $permissions[Acl::PERMISSION_SHARE] ?? false
 				]);
 				$result[$item->getId()] = $item;
 			}
@@ -153,8 +151,7 @@ class BoardService {
 	 * @throws BadRequestException
 	 */
 	public function find($boardId) {
-
-		if ( is_numeric($boardId) === false ) {
+		if (is_numeric($boardId) === false) {
 			throw new BadRequestException('board id must be a number');
 		}
 
@@ -169,10 +166,10 @@ class BoardService {
 		}
 		$permissions = $this->permissionService->matchPermissions($board);
 		$board->setPermissions([
-			'PERMISSION_READ' => $permissions[Acl::PERMISSION_READ],
-			'PERMISSION_EDIT' => $permissions[Acl::PERMISSION_EDIT],
-			'PERMISSION_MANAGE' => $permissions[Acl::PERMISSION_MANAGE],
-			'PERMISSION_SHARE' => $permissions[Acl::PERMISSION_SHARE]
+			'PERMISSION_READ' => $permissions[Acl::PERMISSION_READ] ?? false,
+			'PERMISSION_EDIT' => $permissions[Acl::PERMISSION_EDIT] ?? false,
+			'PERMISSION_MANAGE' => $permissions[Acl::PERMISSION_MANAGE] ?? false,
+			'PERMISSION_SHARE' => $permissions[Acl::PERMISSION_SHARE] ?? false
 		]);
 		$this->enrichWithUsers($board);
 		return $board;
@@ -201,8 +198,7 @@ class BoardService {
 	 * @throws BadRequestException
 	 */
 	public function isArchived($mapper, $id) {
-
-		if (is_numeric($id) === false)  {
+		if (is_numeric($id) === false) {
 			throw new BadRequestException('id must be a number');
 		}
 
@@ -231,12 +227,11 @@ class BoardService {
 	 * @throws BadRequestException
 	 */
 	public function isDeleted($mapper, $id) {
-
 		if ($mapper === false || $mapper === null) {
 			throw new BadRequestException('mapper must be provided');
 		}
 
-		if (is_numeric($id) === false)  {
+		if (is_numeric($id) === false) {
 			throw new BadRequestException('id must be a number');
 		}
 
@@ -264,7 +259,6 @@ class BoardService {
 	 * @throws BadRequestException
 	 */
 	public function create($title, $userId, $color) {
-
 		if ($title === false || $title === null) {
 			throw new BadRequestException('title must be provided');
 		}
@@ -306,10 +300,10 @@ class BoardService {
 		$this->boardMapper->mapOwner($new_board);
 		$permissions = $this->permissionService->matchPermissions($new_board);
 		$new_board->setPermissions([
-			'PERMISSION_READ' => $permissions[Acl::PERMISSION_READ],
-			'PERMISSION_EDIT' => $permissions[Acl::PERMISSION_EDIT],
-			'PERMISSION_MANAGE' => $permissions[Acl::PERMISSION_MANAGE],
-			'PERMISSION_SHARE' => $permissions[Acl::PERMISSION_SHARE]
+			'PERMISSION_READ' => $permissions[Acl::PERMISSION_READ] ?? false,
+			'PERMISSION_EDIT' => $permissions[Acl::PERMISSION_EDIT] ?? false,
+			'PERMISSION_MANAGE' => $permissions[Acl::PERMISSION_MANAGE] ?? false,
+			'PERMISSION_SHARE' => $permissions[Acl::PERMISSION_SHARE] ?? false
 		]);
 		$this->activityManager->triggerEvent(ActivityManager::DECK_OBJECT_BOARD, $new_board, ActivityManager::SUBJECT_BOARD_CREATE);
 		$this->changeHelper->boardChanged($new_board->getId());
@@ -333,7 +327,6 @@ class BoardService {
 	 * @throws BadRequestException
 	 */
 	public function delete($id) {
-
 		if (is_numeric($id) === false) {
 			throw new BadRequestException('board id must be a number');
 		}
@@ -363,7 +356,6 @@ class BoardService {
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 */
 	public function deleteUndo($id) {
-
 		if (is_numeric($id) === false) {
 			throw new BadRequestException('board id must be a number');
 		}
@@ -391,7 +383,7 @@ class BoardService {
 	 * @throws BadRequestException
 	 */
 	public function deleteForce($id) {
-		if (is_numeric($id) === false)  {
+		if (is_numeric($id) === false) {
 			throw new BadRequestException('id must be a number');
 		}
 
@@ -418,7 +410,6 @@ class BoardService {
 	 * @throws BadRequestException
 	 */
 	public function update($id, $title, $color, $archived) {
-
 		if (is_numeric($id) === false) {
 			throw new BadRequestException('board id must be a number');
 		}
@@ -431,7 +422,7 @@ class BoardService {
 			throw new BadRequestException('color must be provided');
 		}
 
-		if ( is_bool($archived) === false ) {
+		if (is_bool($archived) === false) {
 			throw new BadRequestException('archived must be a boolean');
 		}
 
@@ -478,7 +469,6 @@ class BoardService {
 	 * @throws \OCA\Deck\NoPermissionException
 	 */
 	public function addAcl($boardId, $type, $participant, $edit, $share, $manage) {
-
 		if (is_numeric($boardId) === false) {
 			throw new BadRequestException('board id must be a number');
 		}
@@ -528,7 +518,8 @@ class BoardService {
 			try {
 				$resourceProvider = \OC::$server->query(\OCA\Deck\Collaboration\Resources\ResourceProvider::class);
 				$resourceProvider->invalidateAccessCache($boardId);
-			} catch (\Exception $e) {}
+			} catch (\Exception $e) {
+			}
 		}
 
 		$this->eventDispatcher->dispatch(
@@ -550,7 +541,6 @@ class BoardService {
 	 * @throws BadRequestException
 	 */
 	public function updateAcl($id, $edit, $share, $manage) {
-
 		if (is_numeric($id) === false) {
 			throw new BadRequestException('id must be a number');
 		}
@@ -595,7 +585,6 @@ class BoardService {
 	 * @throws BadRequestException
 	 */
 	public function deleteAcl($id) {
-
 		if (is_numeric($id) === false) {
 			throw new BadRequestException('id must be a number');
 		}
@@ -618,7 +607,8 @@ class BoardService {
 			try {
 				$resourceProvider = \OC::$server->query(\OCA\Deck\Collaboration\Resources\ResourceProvider::class);
 				$resourceProvider->invalidateAccessCache($acl->getBoardId());
-			} catch (\Exception $e) {}
+			} catch (\Exception $e) {
+			}
 		}
 		$delete = $this->aclMapper->delete($acl);
 
@@ -629,10 +619,59 @@ class BoardService {
 		return $delete;
 	}
 
+	/**
+	 * @param $id
+	 * @return Board
+	 * @throws DoesNotExistException
+	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
+	 * @throws BadRequestException
+	 */
+	public function clone($id) {
+		if (is_numeric($id) === false) {
+			throw new BadRequestException('board id must be a number');
+		}
+
+		$this->permissionService->checkPermission($this->boardMapper, $id, Acl::PERMISSION_READ);
+
+		$board = $this->boardMapper->find($id);
+		$newBoard = new Board();
+		$newBoard->setTitle($board->getTitle() . ' (' . $this->l10n->t('copy') . ')');
+		$newBoard->setOwner($board->getOwner());
+		$newBoard->setColor($board->getColor());
+		$permissions = $this->permissionService->matchPermissions($board);
+		$newBoard->setPermissions([
+			'PERMISSION_READ' => $permissions[Acl::PERMISSION_READ] ?? false,
+			'PERMISSION_EDIT' => $permissions[Acl::PERMISSION_EDIT] ?? false,
+			'PERMISSION_MANAGE' => $permissions[Acl::PERMISSION_MANAGE] ?? false,
+			'PERMISSION_SHARE' => $permissions[Acl::PERMISSION_SHARE] ?? false
+		]);
+		$this->boardMapper->insert($newBoard);
+
+		$labels = $this->labelMapper->findAll($id);
+		foreach ($labels as $label) {
+			$newLabel = new Label();
+			$newLabel->setTitle($label->getTitle());
+			$newLabel->setColor($label->getColor());
+			$newLabel->setBoardId($newBoard->getId());
+			$this->labelMapper->insert($newLabel);
+		}
+
+		$stacks = $this->stackMapper->findAll($id);
+		foreach ($stacks as $stack) {
+			$newStack = new Stack();
+			$newStack->setTitle($stack->getTitle());
+			$newStack->setBoardId($newBoard->getId());
+			$this->stackMapper->insert($newStack);
+		}
+
+		return $newBoard;
+	}
+
 	private function enrichWithStacks($board, $since = -1) {
 		$stacks = $this->stackMapper->findAll($board->getId(), null, null, $since);
 
-		if(\count($stacks) === 0) {
+		if (\count($stacks) === 0) {
 			return;
 		}
 
@@ -642,7 +681,7 @@ class BoardService {
 	private function enrichWithLabels($board, $since = -1) {
 		$labels = $this->labelMapper->findAll($board->getId(), null, null, $since);
 
-		if(\count($labels) === 0) {
+		if (\count($labels) === 0) {
 			return;
 		}
 
@@ -651,10 +690,9 @@ class BoardService {
 
 	private function enrichWithUsers($board, $since = -1) {
 		$boardUsers = $this->permissionService->findUsers($board->getId());
-		if(\count($boardUsers) === 0) {
+		if (\count($boardUsers) === 0) {
 			return;
 		}
 		$board->setUsers(array_values($boardUsers));
 	}
-
 }
